<?php

// Action Provider class
class ActionProvider
{
	// Communication
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function Signin()
	{
		global $Response;
		global $Settings;
		global $Data;
		
		$Response = CreateElement(VERSION, 'Version') . 
					CreateElement($Settings->SiteTitle, 'Title') . 
					CreateElement($Data['SiteUrl'], 'SiteUrl') . 
					CreateElement('PHP', 'Platform');
	}
	
	
	
	// Configuration
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function ConfigurationGet()
	{
		global $Response;
		global $Settings;
		
		$settingsCollection = $Settings->GetCollection();
		foreach ($settingsCollection as $settingKey => $settingValue)
		{
			$Response .= CreateElement($settingValue, $settingKey);
		}
	}
	
	
	
	public static function ConfigurationSet()
	{
		global $Response;
		global $Settings;
		
		$Settings->Username = RetrieveRequest('AuthUsername');
		if (RetrieveRequest('AuthPassword') != '')
			$Settings->Password = sha1(RetrieveRequest('AuthPassword'));
		$Settings->Offline = StringToBoolean(RetrieveRequest('Offline'));
		$Settings->IncludePageTitle = StringToBoolean(RetrieveRequest('IncludePageTitle'));
		$Settings->SortSubpages = RetrieveRequest('SortSubpages');
		$Settings->ShowParentDescription = StringToBoolean(RetrieveRequest('ShowParentDescription'));
		$Settings->ShowSubpagesDescription = StringToBoolean(RetrieveRequest('ShowSubpagesDescription'));
		$Settings->ErrorReporting = StringToBoolean(RetrieveRequest('ErrorReporting'));
		$Settings->UrlRewriting = StringToBoolean(RetrieveRequest('UrlRewriting'));
		$Settings->UseBaseUrl = StringToBoolean(RetrieveRequest('UseBaseUrl'));
		$Settings->OfflineMessage = RetrieveRequest('OfflineMessage');
		$Settings->SiteTitle = RetrieveRequest('SiteTitle');
		$Settings->EmailAddress = RetrieveRequest('EmailAddress');
		$Settings->MetaDescription = RetrieveRequest('MetaDescription');
		$Settings->MetaKeywords = RetrieveRequest('MetaKeywords');
		$Settings->MetaAuthor = RetrieveRequest('MetaAuthor');
		$Settings->DatabaseType = RetrieveRequest('DatabaseType');
		$Settings->DatabaseHost = RetrieveRequest('DatabaseHost');
		$Settings->DatabaseName = RetrieveRequest('DatabaseName');
		$Settings->DatabaseUsername = RetrieveRequest('DatabaseUsername');
		$Settings->DatabasePassword = RetrieveRequest('DatabasePassword');
		$Settings->DatabaseUsernameAdmin = RetrieveRequest('DatabaseUsernameAdmin');
		$Settings->DatabasePasswordAdmin = RetrieveRequest('DatabasePasswordAdmin');
		$Settings->StylesheetsReferenceType = RetrieveRequest('StylesheetsReferenceType');
		$Settings->ScriptsReferenceType = RetrieveRequest('ScriptsReferenceType');
		$Settings->PostsList = StringToBoolean(RetrieveRequest('PostsList'));
		$Settings->PostsNumber = intval(RetrieveRequest('PostsNumber'));
			
		$Settings->Save();
		if ($Settings->HasError() == TRUE)
			ErrorResponse('21');
		
		StatusOK();
		$Response = '';
	}
	
	
	
	public static function ConfigurationReset()
	{
		global $Response;
		global $Settings;

		if (file_put_contents(CONFIGFILE, file_get_contents(RESOURCESDIR . 'admin/config.xml')) === FALSE)
			ErrorResponse('22');
			
		StatusOK();
		$Response = '';
	}
	
	
	
	public static function MaintenanceDatabaseSetup()
	{
		global $Response;
		global $Settings;
		
		if (!CheckDatabaseSettings())
			ErrorResponse('13');
		
		$mDatabase = new DatabaseManagement($Settings->DatabaseType, $Settings->DatabaseHost, $Settings->DatabaseUsernameAdmin, $Settings->DatabasePasswordAdmin);
		if ($mDatabase->HasError())
			ErrorResponse(30, $mDatabase->ErrorMessage());

		$ptn = array();
		$ptn[0] = '/{DATABASE}/';
		$rlc = array();
		$rlc[0] = $Settings->DatabaseName;
			
		$queryCollection = explode(";", RegexTokenReplacer(RESOURCESDIR . 'admin/database.sql', $ptn, $rlc));
		
		for ($idx = 0; $idx < count($queryCollection); $idx++)
		{
			if (!isset($queryCollection[$idx]) || empty($queryCollection[$idx]))
				unset($queryCollection[$idx]);
		}
	
		$resultCollection = $mDatabase->MultiQuery($queryCollection);
		if ($resultCollection != NULL)
		{
			foreach ($resultCollection as $result)
			{
				if ($result == FALSE)
					ErrorResponse('14');
			}
		}
		else
			ErrorResponse('31');
		
		unset($queryCollection);
		unset($resultCollection);
			
		StatusOK();
		$Response = '';
	}
	
	
	
	// Page
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function PageList()
	{
		global $Response;
		global $Entity;
		
		$pageCollection = $Entity->PageList(TRUE, TRUE, TRUE, FALSE, TRUE, FALSE);
		if ($Entity->HasError())
			ErrorResponse(31, $Entity->ErrorMessage());
		if ($pageCollection == NULL)
		{
			$Response = '';
			return;
		}
		
		foreach ($pageCollection as $page)
		{
			$pageProperties = array();
			$pageProperties['ID'] = $page->ID;
			$pageProperties['Name'] = $page->Name;
			$pageProperties['Title'] = $page->Title;
			$pageProperties['ParentID'] = $page->ParentID;
			
			$Response .= CreateElement('', 'Page', $pageProperties);
			
			unset($pageProperties);
		}
		
		unset($pageCollection);
	}
	
	
	
	public static function PageAdd()
	{
		global $Response;
		global $Database;
		
		$author = '';
		if (RetrieveRequest('Author') == '#')
		{
			global $Settings;
			$author = $Settings->MetaAuthor;
		}
		else
			$author = RetrieveRequest('Author');
		
		$page = new PageEntity();
		$page->ParentID = (int)RetrieveRequest('ParentID');
		$page->Name = RetrieveRequest('Name');
		$page->Title = RetrieveRequest('Title');
		$page->Description = $Database->EscapeString(RetrieveRequest('Description'));
		$page->TextContent = $Database->EscapeString(RetrieveRequest('TextContent'));
		$page->CreatedDate = RetrieveRequest('CreatedDate');
		$page->ModifiedDate = RetrieveRequest('ModifiedDate');
		$page->Published = StringToBoolean(RetrieveRequest('Published'));
		$page->AllowCommenting = StringToBoolean(RetrieveRequest('AllowCommenting'));
		$page->ShowComments = StringToBoolean(RetrieveRequest('ShowComments'));
		$page->ShowSubpages = StringToBoolean(RetrieveRequest('ShowSubpages'));
		$page->ShowTitle = StringToBoolean(RetrieveRequest('ShowTitle'));
		$page->ShowDescription = StringToBoolean(RetrieveRequest('ShowDescription'));
		$page->ShowDate = StringToBoolean(RetrieveRequest('ShowDate'));
		$page->ShowAuthor = StringToBoolean(RetrieveRequest('ShowAuthor'));
		$page->Author = $author;
		$page->MetaDescription = $Database->EscapeString(RetrieveRequest('MetaDescription'));
		$page->MetaKeywords = $Database->EscapeString(RetrieveRequest('MetaKeywords'));
		$page->StyleClass = $Database->EscapeString(RetrieveRequest('StyleClass'));
		
		if (CommandProvider::AddPage($page) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(33, $Database->QueryErrorMessage());
	}
	
	
	
	public static function PageView()
	{
		global $Response;
		global $Entity;
		
		$page = $Entity->Page((int)RetrieveRequest('PageID'));
		if ($Entity->HasError())
			ErrorResponse(31, $Entity->ErrorMessage());
		if ($page == NULL)
			ErrorResponse(32, $Entity->ErrorMessage());
			
		$Response .= CreateElement($page->ID, 'ID');
		$Response .= CreateElement($page->ParentID, 'ParentID');
		$Response .= CreateElement($page->Name, 'Name');
		$Response .= CreateElement($page->Title, 'Title');
		$Response .= CreateElement(CreateCDataValue($page->Description), 'Description');
		$Response .= CreateElement(CreateCDataValue($page->TextContent), 'TextContent');
		$Response .= CreateElement($page->CreatedDate, 'CreatedDate');
		$Response .= CreateElement($page->ModifiedDate, 'ModifiedDate');
		$Response .= CreateElement($page->Counter, 'Counter');
		$Response .= CreateElement(BooleanToString($page->Published), 'Published');
		$Response .= CreateElement(BooleanToString($page->AllowCommenting), 'AllowCommenting');
		$Response .= CreateElement(BooleanToString($page->ShowComments), 'ShowComments');
		$Response .= CreateElement(BooleanToString($page->ShowSubpages), 'ShowSubpages');
		$Response .= CreateElement(BooleanToString($page->ShowTitle), 'ShowTitle');
		$Response .= CreateElement(BooleanToString($page->ShowDescription), 'ShowDescription');
		$Response .= CreateElement(BooleanToString($page->ShowDate), 'ShowDate');
		$Response .= CreateElement(BooleanToString($page->ShowAuthor), 'ShowAuthor');
		$Response .= CreateElement($page->Author, 'Author');
		$Response .= CreateElement($page->MetaDescription, 'MetaDescription');
		$Response .= CreateElement($page->MetaKeywords, 'MetaKeywords');
		$Response .= CreateElement($page->StyleClass, 'StyleClass');
	}
	
	
	
	public static function PageEdit()
	{
		global $Response;
		global $Database;
		
		$name = RetrieveRequest('Name');
		$published = StringToBoolean(RetrieveRequest('Published'));
		$parentid = (int)RetrieveRequest('ParentID');
		if (RetrieveRequest('ID') == '1')
		{
			$name = 'home';
			$published = TRUE;
			$parentid = 0;
		}
		
		$author = RetrieveRequest('Author');
		if (RetrieveRequest('Author') == '#')
		{
			global $Settings;
			$author = $Settings->MetaAuthor;
		}
		
		$page = new PageEntity();
		$page->ID = (int)RetrieveRequest('ID');
		$page->ParentID = $parentid;
		$page->Name = $name;
		$page->Title = RetrieveRequest('Title');
		$page->Description = $Database->EscapeString(RetrieveRequest('Description'));
		$page->TextContent = $Database->EscapeString(RetrieveRequest('TextContent'));
		$page->CreatedDate = RetrieveRequest('CreatedDate');
		$page->ModifiedDate = RetrieveRequest('ModifiedDate');
		$page->Published = $published;
		$page->AllowCommenting = StringToBoolean(RetrieveRequest('AllowCommenting'));
		$page->ShowComments = StringToBoolean(RetrieveRequest('ShowComments'));
		$page->ShowSubpages = StringToBoolean(RetrieveRequest('ShowSubpages'));
		$page->ShowTitle = StringToBoolean(RetrieveRequest('ShowTitle'));
		$page->ShowDescription = StringToBoolean(RetrieveRequest('ShowDescription'));
		$page->ShowDate = StringToBoolean(RetrieveRequest('ShowDate'));
		$page->ShowAuthor = StringToBoolean(RetrieveRequest('ShowAuthor'));
		$page->Author = $author;
		$page->MetaDescription = $Database->EscapeString(RetrieveRequest('MetaDescription'));
		$page->MetaKeywords = $Database->EscapeString(RetrieveRequest('MetaKeywords'));
		$page->StyleClass = $Database->EscapeString(RetrieveRequest('StyleClass'));
		
		if (CommandProvider::EditPage($page) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(33, $Database->QueryErrorMessage());
	}
	
	
	
	public static function PageDelete()
	{
		global $Response;
		global $Database;
		
		if (RetrieveRequest('PageID') == '1')
			ErrorResponse(33, "Can't delete home page.");
		
		if (CommandProvider::DeletePagePanels(RetrieveRequest('PageID')) == FALSE)
			ErrorResponse(33, "Can't delete page panels. " . "\n" . $Database->QueryErrorMessage());
		
		if (CommandProvider::DeletePageComments(RetrieveRequest('PageID')) == FALSE)
			ErrorResponse(33, "Can't delete page comments. " . "\n" . $Database->QueryErrorMessage());
		
		if (CommandProvider::DeletePage(RetrieveRequest('PageID')) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(33, $Database->QueryErrorMessage());
	}
	
	
	
	// Menu
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function MenuAdd()
	{
		global $Response;
		
		$menu = new MenuEntity();
		$menu->MenuGroup = (int)RetrieveRequest('MenuGroup');
		$menu->Title = RetrieveRequest('Title');
		$menu->AltText = RetrieveRequest('AltText');
		$menu->PageURL = RetrieveRequest('PageURL');
		$menu->Ordering = (int)RetrieveRequest('Ordering');
		$menu->Published = StringToBoolean(RetrieveRequest('Published'));
		$menu->IsExternal = StringToBoolean(RetrieveRequest('IsExternal'));

		if (CommandProvider::AddMenu($menu) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
		{
			global $Database;
			ErrorResponse(33, $Database->QueryErrorMessage());
		}
	}
	
	
	
	public static function MenuList()
	{
		global $Response;
		global $Entity;
		
		$menuCollection = $Entity->Menus();
		if ($Entity->HasError())
			ErrorResponse(31, $Entity->ErrorMessage());
		if ($menuCollection == NULL)
		{
			$Response = '';
			return;
		}
		
		foreach ($menuCollection as $menu)
		{
			$Response .= CreateElement(CreateElement($menu->ID, 'ID') . CreateElement($menu->MenuGroup, 'MenuGroup') . CreateElement($menu->Title, 'Title') . CreateElement($menu->AltText, 'AltText') . CreateElement(htmlspecialchars($menu->PageURL, ENT_QUOTES), 'PageURL') . CreateElement($menu->Ordering, 'Ordering') . CreateElement(BooleanToString($menu->Published), 'Published') . CreateElement(BooleanToString($menu->IsExternal), 'IsExternal'), 'Menu');
		}
		
		unset($menuCollection);
	}
	
	
	
	public static function MenuEdit()
	{
		global $Response;
		
		$menu = new MenuEntity();
		$menu->ID = (int)RetrieveRequest('ID');
		$menu->MenuGroup = (int)RetrieveRequest('MenuGroup');
		$menu->Title = RetrieveRequest('Title');
		$menu->AltText = RetrieveRequest('AltText');
		$menu->PageURL = RetrieveRequest('PageURL');
		$menu->Ordering = (int)RetrieveRequest('Ordering');
		$menu->Published = StringToBoolean(RetrieveRequest('Published'));
		$menu->IsExternal = StringToBoolean(RetrieveRequest('IsExternal'));

		if (CommandProvider::EditMenu($menu) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
		{
			global $Database;
			ErrorResponse(33, $Database->QueryErrorMessage());
		}
	}
	
	
	
	public static function MenuDelete()
	{
		global $Response;
		
		if (CommandProvider::DeleteMenu(RetrieveRequest('MenuID')) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
		{
			global $Database;
			ErrorResponse(33, $Database->QueryErrorMessage());
		}
	}
	
	
	
	public static function MenuOrdering()
	{
		global $Response;
		global $RequestCollection;
		
		$orderCollection = array();
		$valueCollection = array();
		
		$itemCollection = RetrieveRequestArray('Item');
		if ($itemCollection != NULL)
		{
			foreach ($itemCollection as $item)
			{
				parse_str($item, $valueCollection);
				$orderCollection[] = $valueCollection;
				
				unset($valueCollection);
			}
		}
		else
			ErrorResponse(15);
		
		unset($itemCollection);
		
		
		$resultCollection = CommandProvider::OrderingMenu($orderCollection);
		if ($resultCollection != NULL)
		{
			foreach ($resultCollection as $result)
			{
				if ($result == FALSE)
					ErrorResponse('34');
			}
		}
		else
			ErrorResponse('31');
		
		unset($resultCollection);
		unset($orderCollection);
			
		StatusOK();
		$Response = '';
	}
	
	
	
	// Panel
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function PanelAdd()
	{
		global $Response;
		global $Database;
		
		$panel = new PanelEntity();
		$panel->PageID = (int)RetrieveRequest('PageID');
		$panel->PanelGroup = (int)RetrieveRequest('PanelGroup');
		$panel->Title = RetrieveRequest('Title');
		$panel->TextContent = $Database->EscapeString(RetrieveRequest('TextContent'));
		$panel->ShowOnSubpages = StringToBoolean(RetrieveRequest('ShowOnSubpages'));
		$panel->ShowGlobal = StringToBoolean(RetrieveRequest('ShowGlobal'));
		$panel->StyleClass = $Database->EscapeString(RetrieveRequest('StyleClass'));
		
		if (CommandProvider::AddPanel($panel) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(33, $Database->QueryErrorMessage());
	}
	
	
	
	public static function PanelList()
	{
		global $Response;
		global $Entity;
		global $ThisPage;
		
		$ThisPage->ID = (int)RetrieveRequest('PageID');
		
		$panelCollection = NULL;
		if ($ThisPage->ID == 0)
			$panelCollection = $Entity->PanelList('ALL');
		else
			$panelCollection = $Entity->PanelList();
		if ($Entity->HasError())
			ErrorResponse(31, $Entity->ErrorMessage());
		if ($panelCollection == NULL)
		{
			$Response = '';
			return;
		}
		
		foreach ($panelCollection as $panel)
		{
			$Response .= CreateElement(CreateElement($panel->ID, 'ID') . CreateElement($panel->Title, 'Title'), 'PanelItem');
		}
		
		unset($panelCollection);
	}
	
	
	
	public static function PanelView()
	{
		global $Response;
		global $Entity;
		
		$panel = $Entity->Panel((int)RetrieveRequest('PanelID'));
		if ($Entity->HasError())
			ErrorResponse(31, $Entity->ErrorMessage());
		if ($panel == NULL)
			ErrorResponse(32, $Entity->ErrorMessage());
			
		$Response .= CreateElement($panel->ID, 'ID');
		$Response .= CreateElement($panel->PageID, 'PageID');
		$Response .= CreateElement($panel->PanelGroup, 'PanelGroup');
		$Response .= CreateElement($panel->Title, 'Title');
		$Response .= CreateElement(CreateCDataValue($panel->TextContent), 'TextContent');
		$Response .= CreateElement(BooleanToString($panel->ShowOnSubpages), 'ShowOnSubpages');
		$Response .= CreateElement(BooleanToString($panel->ShowGlobal), 'ShowGlobal');
		$Response .= CreateElement(htmlspecialchars($panel->StyleClass), 'StyleClass');
	}
	
	
	
	public static function PanelEdit()
	{
		global $Response;
		global $Database;
		
		$panel = new PanelEntity();
		$panel->ID = (int)RetrieveRequest('ID');
		$panel->PageID = (int)RetrieveRequest('PageID');
		$panel->PanelGroup = (int)RetrieveRequest('PanelGroup');
		$panel->Title = RetrieveRequest('Title');
		$panel->TextContent = $Database->EscapeString(RetrieveRequest('TextContent'));
		$panel->ShowOnSubpages = StringToBoolean(RetrieveRequest('ShowOnSubpages'));
		$panel->ShowGlobal = StringToBoolean(RetrieveRequest('ShowGlobal'));
		$panel->StyleClass = $Database->EscapeString(RetrieveRequest('StyleClass'));
		
		if (CommandProvider::EditPanel($panel) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(33, $Database->QueryErrorMessage());
	}
	
	
	
	public static function PanelDelete()
	{
		global $Response;
		
		if (CommandProvider::DeletePanel(RetrieveRequest('PanelID')) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
		{
			global $Database;
			ErrorResponse(33, $Database->QueryErrorMessage());
		}
	}
	
	
	
	// Comment
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function CommentList()
	{
		global $Response;
		global $Entity;
		global $ThisPage;
		
		$ThisPage->ID = (int)RetrieveRequest('PageID');
				
		$commentCollection = $Entity->Comments();
		if ($Entity->HasError())
			ErrorResponse(31, $Entity->ErrorMessage());
		if ($commentCollection == NULL)
		{
			$Response = '';
			return;
		}
			
		foreach ($commentCollection as $comment)
		{
			$Response .= CreateElement(CreateElement($comment->ID, 'ID') . CreateElement($comment->NamePerson, 'NamePerson') . CreateElement($comment->Email, 'Email') . CreateElement($comment->Subject, 'Subject') . CreateElement(CreateCDataValue($comment->Message), 'Message') . CreateElement($comment->CreatedDate, 'CreatedDate'), 'Comment');
		}
		
		unset($commentCollection);
	}
	
	
	
	public static function CommentDelete()
	{
		global $Response;
		global $RequestCollection;
		
		$commentCollection = RetrieveRequestArray('CommentID');
		if ($commentCollection != NULL)
		{
			$resultCollection = CommandProvider::DeleteComments($commentCollection);
			if ($resultCollection != NULL)
			{
				foreach ($resultCollection as $result)
				{
					if ($result == FALSE)
						ErrorResponse('34');
				}
			}
			else
				ErrorResponse('31');
				
			unset($resultCollection);
		}
		else
			ErrorResponse(15);
			
		unset($commentCollection);
		
		StatusOK();
		$Response = '';
	}
	
	
			
	// Module
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function ModuleList()
	{
		global $Response;
		global $Modules;
		
		$settingArray = array();
		
		$panelCollection = $Modules->GetPanelModuleCollection();
		foreach ($panelCollection as $panelModule)
		{
			$settingContent = '';
			foreach($panelModule->Settings as $settingName => $settingValue)
			{
				$settingArray['Name'] = $settingName;
				$settingArray['Value'] = $settingValue;
				$settingContent .= CreateElement('', 'Item', $settingArray);
			}
			
			$Response .= CreateElement(CreateElement($panelModule->ID, 'ID') . 
						 CreateElement($panelModule->Name, 'Name') . 
						 CreateElement(BooleanToString($panelModule->Actived), 'Actived') . 
						 CreateElement($panelModule->Title, 'Title') . 
						 CreateElement($panelModule->Panel, 'Panel') . 
						 CreateElement($panelModule->StyleClass, 'StyleClass') . 
						 CreateElement(BooleanToString($panelModule->IsGlobal), 'IsGlobal') . 
						 CreateElement(BooleanToString($panelModule->AlwaysShow), 'AlwaysShow') . 
						 CreateElement($settingContent, 'Settings'), 'PanelModule');
		}
		
		unset($panelCollection);
	}
	
	
	
	public static function ModulePanelEdit()
	{
		global $Response;
		global $Modules;
		global $RequestCollection;
		
		$panelModule = new PanelModuleEntity();
		$panelModule->ID = (int)RetrieveRequest('ID');
		$panelModule->Actived = StringToBoolean(RetrieveRequest('Actived'));
		$panelModule->Title = RetrieveRequest('Title');
		$panelModule->Panel = (int)RetrieveRequest('Panel');
		$panelModule->StyleClass = RetrieveRequest('StyleClass');
		$panelModule->IsGlobal = StringToBoolean(RetrieveRequest('IsGlobal'));
		$panelModule->AlwaysShow = StringToBoolean(RetrieveRequest('AlwaysShow'));
		$panelModule->Settings = array();
		
		$valueCollection = array();
		$sc = array();
		
		$itemCollection = RetrieveRequestArray('Setting');
		if ($itemCollection != NULL)
		{
			foreach ($itemCollection as $item)
			{
				parse_str($item, $settingCollection);
				$panelModule->Settings[$settingCollection['Name']] = $settingCollection['Value'];
			}
		}
			
		if ($Modules->EditPanelModule($panelModule) == TRUE)
		{
			$Modules->Save();
			if ($Modules->HasError() == TRUE)
				ErrorResponse('51');
				
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(52);
	}
	
	
	
	// Media
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function MediaList()
	{
		global $Response;
		
		$mediaCollection = MediaSystem::ListMedia(RetrieveRequest('Folder'));
		if ($mediaCollection === FALSE)
			ErrorResponse(70);
			
		foreach ($mediaCollection as $media)
		{
			$Response .= CreateElement(CreateElement($media->Name, 'Name') . CreateElement($media->Size, 'Size'), 'File');
		}
		
		unset($mediaCollection);
	}
	
	
	
	public static function MediaAdd()
	{
		global $Response;
		
		if (MediaSystem::AddMedia(RetrieveRequest('Folder'), RetrieveRequest('Filename'), base64_decode(RetrieveRequest('Content'))) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(72);
	}
	
	
	
	public static function MediaDelete()
	{
		global $Response;
		
		if (MediaSystem::DeleteMedia(RetrieveRequest('Folder'), RetrieveRequest('Filename')) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(73);
	}
	
	
	
	public static function MediaView()
	{
		global $Response;
		
		$mediaContent = MediaSystem::ViewMedia(RetrieveRequest('Folder'), RetrieveRequest('Filename'));
		if ($mediaContent === FALSE)
			ErrorResponse(74);
		
		$Response = CreateElement(RetrieveRequest('Filename'), 'Name');
		$Response .= CreateElement(base64_encode($mediaContent), 'Content');
	}
	
	
	
	// Theme
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function ThemeElements()
	{
		global $Response;
		global $ThemeSystem;
		
		foreach ($ThemeSystem->GetStylesheets() as $stylesheet)
		{
			$Response .= CreateElement(CreateElement($stylesheet->Filename, 'Filename') . CreateElement($stylesheet->Condition, 'Condition'), 'Stylesheet');
		}
		
		foreach ($ThemeSystem->GetScripts() as $script)
		{
			$Response .= CreateElement(CreateElement($script->Filename, 'Filename') . CreateElement($script->Condition, 'Condition'), 'Script');
		}
		
		foreach (ThemeSystem::GetTemplates() as $template)
		{
			$Response .= CreateElement(CreateElement($template, 'Filename'), 'Template');
		}
	}
	
	
	
	public static function ThemeElementView()
	{
		global $Response;
		
		$Response .= CreateElement(RetrieveRequest('Filename'), 'Name');
		$content;
		
		switch (strtoupper(RetrieveRequest('ElementType')))
		{
			case 'SKIN':
				$content = ThemeSystem::GetSkinContent();
				break;
			case 'STYLESHEET':
				$content = ThemeSystem::GetStylesheetContent(RetrieveRequest('Filename'));
				break;
			case 'SCRIPT':
				$content = ThemeSystem::GetScriptContent(RetrieveRequest('Filename'));
				break;
			default:
				ErrorResponse(81);
		}
		
		if ($content === FALSE)
			ErrorResponse(82);
		
		$Response .= CreateElement(CreateCDataValue($content), 'Content');
	}
	
	
	
	public static function ThemeElementEdit()
	{
		$result;
		switch (strtoupper(RetrieveRequest('ElementType')))
		{
			case 'SKIN':
				$result = ThemeSystem::SetSkinContent(RetrieveRequest('Content'));
				break;
			case 'STYLESHEET':
				$result = ThemeSystem::SetStylesheetContent(RetrieveRequest('Filename'), RetrieveRequest('Content'));
				break;
			case 'SCRIPT':
				$result = ThemeSystem::SetScriptContent(RetrieveRequest('Filename'), RetrieveRequest('Content'));
				break;
			default:
				ErrorResponse(81);
		}
		
		if ($result === FALSE)
			ErrorResponse(83);
			
		StatusOK();
		$Response = '';
	}
	
	
	
	public static function ThemeTemplateView()
	{
		global $Response;
				
		$content = ThemeSystem::GetTemplateContent(RetrieveRequest('Filename'));
		if ($content === FALSE)
			ErrorResponse(82);
		
		$Response .= CreateElement(RetrieveRequest('Filename'), 'Name');
		$Response .= CreateElement(CreateCDataValue($content), 'Content');
	}
	
	
	
	public static function ThemeTemplateEdit()
	{
		$result = ThemeSystem::SetTemplateContent(RetrieveRequest('Filename'), RetrieveRequest('Content'));
		
		if ($result === FALSE)
			ErrorResponse(83);
			
		StatusOK();
		$Response = '';
	}
	
	
	
	// Post
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
	public static function PostList()
	{
		global $Response;
		global $Entity;
		
		$postCollection = $Entity->PostList(TRUE, TRUE, TRUE, FALSE);
		if ($Entity->HasError())
			ErrorResponse(31, $Entity->ErrorMessage());
		if ($postCollection == NULL)
		{
			$Response = '';
			return;
		}
		
		foreach ($postCollection as $post)
		{
			$postProperties = array();
			$postProperties['ID'] = $post->ID;
			$postProperties['Name'] = $post->Name;
			$postProperties['Title'] = $post->Title;
			
			$Response .= CreateElement('', 'Post', $postProperties);
			
			unset($postProperties);
		}
		
		unset($postCollection);
	}
	
	
	
	public static function PostAdd()
	{
		global $Response;
		global $Database;
		
		$author = '';
		if (RetrieveRequest('Author') == '#')
		{
			global $Settings;
			$author = $Settings->MetaAuthor;
		}
		else
			$author = RetrieveRequest('Author');
		
		$post = new PostEntity();
		$post->Name = RetrieveRequest('Name');
		$post->Title = RetrieveRequest('Title');
		$post->TextContent = $Database->EscapeString(RetrieveRequest('TextContent'));
		$post->CreatedDate = RetrieveRequest('CreatedDate');
		$post->ModifiedDate = RetrieveRequest('ModifiedDate');
		$post->Published = StringToBoolean(RetrieveRequest('Published'));
		$post->ShowAuthor = StringToBoolean(RetrieveRequest('ShowAuthor'));
		$post->Author = $author;
		$post->MetaDescription = $Database->EscapeString(RetrieveRequest('MetaDescription'));
		$post->MetaKeywords = $Database->EscapeString(RetrieveRequest('MetaKeywords'));
		$post->StyleClass = $Database->EscapeString(RetrieveRequest('StyleClass'));
		
		if (CommandProvider::AddPost($post) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(33, $Database->QueryErrorMessage());
	}
	
	
	
	public static function PostEdit()
	{
		global $Response;
		global $Database;
		
		$name = RetrieveRequest('Name');
		$published = StringToBoolean(RetrieveRequest('Published'));
		$author = RetrieveRequest('Author');
		if (RetrieveRequest('Author') == '#')
		{
			global $Settings;
			$author = $Settings->MetaAuthor;
		}
		
		$post = new PostEntity();
		$post->ID = (int)RetrieveRequest('ID');
		$post->Name = $name;
		$post->Title = RetrieveRequest('Title');
		$post->TextContent = $Database->EscapeString(RetrieveRequest('TextContent'));
		$post->CreatedDate = RetrieveRequest('CreatedDate');
		$post->ModifiedDate = RetrieveRequest('ModifiedDate');
		$post->Published = $published;
		$post->ShowAuthor = StringToBoolean(RetrieveRequest('ShowAuthor'));
		$post->Author = $author;
		$post->MetaDescription = $Database->EscapeString(RetrieveRequest('MetaDescription'));
		$post->MetaKeywords = $Database->EscapeString(RetrieveRequest('MetaKeywords'));
		$post->StyleClass = $Database->EscapeString(RetrieveRequest('StyleClass'));
		
		if (CommandProvider::EditPost($post) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(33, $Database->QueryErrorMessage());
	}
	
	
	
	public static function PostView()
	{
		global $Response;
		global $Entity;
		
		$post = $Entity->Post((int)RetrieveRequest('PostID'));
		if ($Entity->HasError())
			ErrorResponse(31, $Entity->ErrorMessage());
		if ($post == NULL)
			ErrorResponse(32, $Entity->ErrorMessage());
			
		$Response .= CreateElement($post->ID, 'ID');
		$Response .= CreateElement($post->Name, 'Name');
		$Response .= CreateElement($post->Title, 'Title');
		$Response .= CreateElement(CreateCDataValue($post->TextContent), 'TextContent');
		$Response .= CreateElement($post->CreatedDate, 'CreatedDate');
		$Response .= CreateElement($post->ModifiedDate, 'ModifiedDate');
		$Response .= CreateElement($post->Counter, 'Counter');
		$Response .= CreateElement(BooleanToString($post->Published), 'Published');
		$Response .= CreateElement(BooleanToString($post->ShowAuthor), 'ShowAuthor');
		$Response .= CreateElement($post->Author, 'Author');
		$Response .= CreateElement($post->MetaDescription, 'MetaDescription');
		$Response .= CreateElement($post->MetaKeywords, 'MetaKeywords');
		$Response .= CreateElement($post->StyleClass, 'StyleClass');
	}
	
	
	
	public static function PostDelete()
	{
		global $Response;
		global $Database;
		
		if (CommandProvider::DeletePost(RetrieveRequest('PostID')) == TRUE)
		{
			StatusOK();
			$Response = '';
		}
		else
			ErrorResponse(33, $Database->QueryErrorMessage());
	}

	
	
	// ------------------------------------------------------------------------------------------------------------------------------------------
	
}

?>