<?php

// Settings and configuration system class
class SettingsManagement
{
	public $Username;
	public $Password;
	public $Offline;
	public $OfflineMessage;
	public $SiteTitle;
	public $IncludePageTitle;
	public $SortSubpages;
	public $ShowParentDescription;
	public $ShowSubpagesDescription;
	public $ErrorReporting;
	public $UrlRewriting;
	public $UseBaseUrl;
	public $StylesheetsReferenceType;
	public $ScriptsReferenceType;
	public $EmailAddress;
	public $MetaDescription;
	public $MetaKeywords;
	public $MetaAuthor;
	public $DatabaseType;
	public $DatabaseHost;
	public $DatabaseName;
	public $DatabaseUsername;
	public $DatabasePassword;
	public $DatabaseUsernameAdmin;
	public $DatabasePasswordAdmin;
	public $PostsList;
	public $PostsNumber;

	
	private $XDocSettings;
	private $Error;
	
	
	
	
	
	// Settings Management constructor
	function __construct()
	{
		$this->Error = FALSE;
		
		// Instantiate XML Document and Load Configuration file
		$this->XDocSettings = new DOMDocument();
		if ($this->XDocSettings->load(CONFIGFILE) == FALSE)
			$this->Error = TRUE;
		else
			$this->Error = FALSE;
	}
	
	
	
	// Settings Management destructor
	function __destruct()
	{
		unset($this->XDocSettings);
	}
	
	
	
	public function Load()
	{
		// Load configuration to settings fields
		$SettingElements = $this->XDocSettings->documentElement->childNodes;
		foreach ($SettingElements as $element)
		{
			if ($element->nodeType != XML_ELEMENT_NODE)
				continue;
				
			switch (strtoupper($element->nodeName))
			{
				case 'USERNAME':
					$this->Username = $element->nodeValue;
					break;
				case 'PASSWORD':
					$this->Password = $element->nodeValue;
					break;
				case 'OFFLINE':
					$this->Offline = StringToBoolean($element->nodeValue);
					break;
				case 'OFFLINEMESSAGE':
					$this->OfflineMessage = $element->nodeValue;
					break;
				case 'SITETITLE':
					$this->SiteTitle = $element->nodeValue;
					break;
				case 'INCLUDEPAGETITLE':
					$this->IncludePageTitle = StringToBoolean($element->nodeValue);
					break;
				case 'SORTSUBPAGES':
					$this->SortSubpages = strtolower($element->nodeValue);
					break;
				case 'SHOWPARENTDESCRIPTION':
					$this->ShowParentDescription = StringToBoolean($element->nodeValue);
					break;
				case 'SHOWSUBPAGESDESCRIPTION':
					$this->ShowSubpagesDescription = StringToBoolean($element->nodeValue);
					break;
				case 'ERRORREPORTING':
					$this->ErrorReporting = StringToBoolean($element->nodeValue);
					break;
				case 'URLREWRITING':
					$this->UrlRewriting = StringToBoolean($element->nodeValue);
					break;
				case 'USEBASEURL':
					$this->UseBaseUrl = StringToBoolean($element->nodeValue);
					break;
				case 'STYLESHEETSREFERENCETYPE':
					$this->StylesheetsReferenceType = strtolower($element->nodeValue);
					break;
				case 'SCRIPTSREFERENCETYPE':
					$this->ScriptsReferenceType = strtolower($element->nodeValue);
					break;
				case 'EMAILADDRESS':
					$this->EmailAddress = $element->nodeValue;
					break;
				case 'METADESCRIPTION':
					$this->MetaDescription = $element->nodeValue;
					break;
				case 'METAKEYWORDS':
					$this->MetaKeywords = $element->nodeValue;
					break;
				case 'METAAUTHOR':
					$this->MetaAuthor = $element->nodeValue;
					break;
				case 'DATABASETYPE':
					$this->DatabaseType = strtolower($element->nodeValue);
					break;
				case 'DATABASEHOST':
					$this->DatabaseHost = $element->nodeValue;
					break;
				case 'DATABASENAME':
					$this->DatabaseName = $element->nodeValue;
					break;
				case 'DATABASEUSERNAME':
					$this->DatabaseUsername = $element->nodeValue;
					break;
				case 'DATABASEPASSWORD':
					$this->DatabasePassword = $element->nodeValue;
					break;
				case 'DATABASEUSERNAMEADMIN':
					$this->DatabaseUsernameAdmin = $element->nodeValue;
					break;
				case 'DATABASEPASSWORDADMIN':
					$this->DatabasePasswordAdmin = $element->nodeValue;
					break;
				case 'POSTSLIST':
					$this->PostsList = StringToBoolean($element->nodeValue);
					break;
				case 'POSTSNUMBER':
					$this->PostsNumber = intval($element->nodeValue);
					break;
			}			
		}
		
		$this->Error = false;
	}
	
	
	
	
	public function Save()
	{
		// Get configuration elements and save settings to configuration element
		$SettingElements = $this->XDocSettings->documentElement->childNodes;
		foreach ($SettingElements as $element)
		{
			if ($element->nodeType != XML_ELEMENT_NODE)
				continue;
				
			switch (strtoupper($element->nodeName))
			{
				case 'USERNAME':
					$element->nodeValue = $this->Username;
					break;
				case 'PASSWORD':
					$element->nodeValue = $this->Password;
					break;
				case 'OFFLINE':
					$element->nodeValue = BooleanToString($this->Offline);
					break;
				case 'OFFLINEMESSAGE':
					$element->nodeValue = $this->OfflineMessage;
					break;
				case 'SITETITLE':
					$element->nodeValue = $this->SiteTitle;
					break;
				case 'INCLUDEPAGETITLE':
					$element->nodeValue = BooleanToString($this->IncludePageTitle);
					break;
				case 'SORTSUBPAGES':
					$element->nodeValue = strtolower($this->SortSubpages);
					break;
				case 'SHOWPARENTDESCRIPTION':
					$element->nodeValue = BooleanToString($this->ShowParentDescription);
					break;
				case 'SHOWSUBPAGESDESCRIPTION':
					$element->nodeValue = BooleanToString($this->ShowSubpagesDescription);
					break;
				case 'ERRORREPORTING':
					$element->nodeValue = BooleanToString($this->ErrorReporting);
					break;
				case 'URLREWRITING':
					$element->nodeValue = BooleanToString($this->UrlRewriting);
					break;
				case 'USEBASEURL':
					$element->nodeValue = BooleanToString($this->UseBaseUrl);
					break;
				case 'STYLESHEETSREFERENCETYPE':
					$element->nodeValue = strtolower($this->StylesheetsReferenceType);
					break;
				case 'SCRIPTSREFERENCETYPE':
					$element->nodeValue = strtolower($this->ScriptsReferenceType);
					break;
				case 'EMAILADDRESS':
					$element->nodeValue = $this->EmailAddress;
					break;
				case 'METADESCRIPTION':
					$element->nodeValue = $this->MetaDescription;
					break;
				case 'METAKEYWORDS':
					$element->nodeValue = $this->MetaKeywords;
					break;
				case 'METAAUTHOR':
					$element->nodeValue = $this->MetaAuthor;
					break;
				case 'DATABASETYPE':
					$element->nodeValue = strtolower($this->DatabaseType);
					break;
				case 'DATABASEHOST':
					$element->nodeValue = $this->DatabaseHost;
					break;
				case 'DATABASENAME':
					$element->nodeValue = $this->DatabaseName;
					break;
				case 'DATABASEUSERNAME':
					$element->nodeValue = $this->DatabaseUsername;
					break;
				case 'DATABASEPASSWORD':
					$element->nodeValue = $this->DatabasePassword;
					break;
				case 'DATABASEUSERNAMEADMIN':
					$element->nodeValue = $this->DatabaseUsernameAdmin;
					break;
				case 'DATABASEPASSWORDADMIN':
					$element->nodeValue = $this->DatabasePasswordAdmin;
					break;
				case 'POSTSLIST':
					$element->nodeValue = BooleanToString($this->PostsList);
					break;
				case 'POSTSNUMBER':
					$element->nodeValue = strval($this->PostsNumber);
					break;
			}
		}
		
		// Save settings to configuration file
		if($this->XDocSettings->save(CONFIGFILE) == false)
			$this->Error = true;
		else
			$this->Error = false;
	}
	
	
	
	// Has configuration error
	// Return: boolean
	public function HasError()
	{
		return $this->Error;
	}
	
	
	
	// Get settings fields as collection
	// Return: Associative Array
	public function GetCollection()
	{
		$settingsCollection = array();
		
		$SettingElements = $this->XDocSettings->documentElement->childNodes;
		foreach ($SettingElements as $element)
		{
			if ($element->nodeType != XML_ELEMENT_NODE)
				continue;
				
			$settingsCollection[$element->nodeName] = $element->nodeValue;
		}
		
		return $settingsCollection;
	}
	
}

?>