<?php

// Content Provider class
class ContentProvider
{
	// Provide page content
	public static function Page()
	{
		global $Entity;
		global $ThisPage;
		global $Output;
		global $Settings;
		global $Data;
		global $Store;
		global $Request;
		
		$page = $Entity->Page($Request);
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `PAGE` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($page != NULL && $page->Published == TRUE)
		{
			$ThisPage->ID = $page->ID;
			$ThisPage->ParentID = $page->ParentID;
			$ThisPage->Name = $page->Name;
			
			CommandProvider::IncreasePageCounter($ThisPage->ID, $page->Counter + 1);
			
			$content = '';
			
			// Prepare parent description
			if ($Settings->ShowParentDescription == TRUE && $page->ParentID > 0)
			{
				$pdescription = $Entity->ParentDescription($page->ParentID);
				if ($Entity->HasError())
					ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `Parent Description` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
				if ($pdescription != NULL)
					$content .= TemplateProvider::ContentParentDescription($pdescription);
			}
			
			// Prepare author
			if ($page->ShowAuthor == true && empty($page->Author) == FALSE)
				$content .= TemplateProvider::ContentAuthor($page->Author);
				
			// Prepare date
			if ($page->ShowDate == true)
			{
				$timestampCreated = strtotime($page->CreatedDate);
				$timestampModified = strtotime($page->ModifiedDate);
				$content .= TemplateProvider::ContentDate(date("l, d F Y", $timestampCreated), date("m-d-Y", $timestampCreated), date("l, d F Y", $timestampModified), date("m-d-Y", $timestampModified), date("H:i", $timestampCreated), date("H:i", $timestampModified));
			}
			
			// Prepare description
			if ($page->ShowDescription == true && empty($page->Description) == FALSE)
				$content .= TemplateProvider::ContentDescription($page->Description);
			
			// Prepare content text
			$content .= TemplateProvider::ContentText($page->TextContent);
			
			// Prepare subpages
			if ($page->ShowSubpages == true)
				$content .= self::Subpage();
			
			// Prepare posts
			if (IsHomePage() && $Settings->PostsList == TRUE)
			{
				$postsInfo = self::PostsList(1);
				if ($postsInfo != NULL)
					$content .= $postsInfo->Content;
			}
			
			// Prepare commenting form
			if ($page->AllowCommenting == true)
				$content .= TemplateProvider::FormComment($ThisPage->ID);
			
			$Output['Content'] = TemplateProvider::Content($content, $page->StyleClass);
			if ($page->ShowTitle == true)
				$Output['PageTitle'] = $page->Title;
			
			// Prepare comments
			if ($page->ShowComments == TRUE)
				self::Comment();
				
			// Set meta
			$Store['Author'] = $page->Author;
			$Store['Description'] = $page->MetaDescription;
			$Store['Keywords'] = $page->MetaKeywords;
			
			// Prepare global variables
			$Data['HasContent'] = TRUE;
		}
		else
			self::PageNotFound();
	}
	
	
	
	// Provide post content
	public static function Post()
	{
		global $Entity;
		global $ThisPost;
		global $Output;
		global $Data;
		global $Store;
		global $Request;
		
		$post = $Entity->Post($Request);
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `POST` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($post != NULL && $post->Published == TRUE)
		{
			$ThisPost->ID = $post->ID;
			$ThisPost->Name = $post->Name;
			
			CommandProvider::IncreasePostCounter($ThisPost->ID, $post->Counter + 1);
			
			$content = '';
			
			// Prepare author
			if ($post->ShowAuthor == true && empty($post->Author) == FALSE)
				$content .= TemplateProvider::PostContentAuthor($post->Author);
			
			// Prepare date
			$timestampCreated = strtotime($post->CreatedDate);
			$timestampModified = strtotime($post->ModifiedDate);
			$content .= TemplateProvider::PostContentDate(date("l, d F Y", $timestampCreated), date("m-d-Y", $timestampCreated), date("l, d F Y", $timestampModified), date("m-d-Y", $timestampModified), date("H:i", $timestampCreated), date("H:i", $timestampModified));
			
			// Prepare content text
			$content .= TemplateProvider::PostContentText($post->TextContent);
			
			$Output['Content'] = TemplateProvider::PostContent($content, $post->StyleClass);
			$Output['PageTitle'] = $post->Title;
				
			// Set meta
			$Store['Author'] = $post->Author;
			$Store['Description'] = $post->MetaDescription;
			$Store['Keywords'] = $post->MetaKeywords;
			
			// Prepare global variables
			$Data['HasContent'] = TRUE;
		}
		else
			self::PostNotFound();
	}
	
	
	
	// Provide PageNotFound content
	public static function PageNotFound()
	{
		global $Request;
		global $Output;
		global $Settings;
		
		$Output['PageTitle'] = 'Page not found';
		$Output['Content'] = TemplateProvider::Content(TemplateProvider::PageNotFound($Request, $Output['Title'], 'mailto:' . $Settings->EmailAddress), 'pagenotfound');
		
		// Prepare global variables
		$Data['HasContent'] = FALSE;
	}
	
	
	
	// Provide PostNotFound content
	public static function PostNotFound()
	{
		global $Request;
		global $Output;
		global $Settings;
		
		$Output['PageTitle'] = 'Post not found';
		$Output['Content'] = TemplateProvider::PostContent(TemplateProvider::PostNotFound($Request, $Output['Title'], 'mailto:' . $Settings->EmailAddress), 'postnotfound');
		
		// Prepare global variables
		$Data['HasContent'] = FALSE;
	}
	
	
	
	// Provide PostsNotFound content
	public static function PostsListNotFound()
	{
		global $Output;
		global $Settings;
		
		$Output['PageTitle'] = 'Posts not found';
		$Output['Content'] = TemplateProvider::PostContent(TemplateProvider::PostsListNotFound($Output['Title'], 'mailto:' . $Settings->EmailAddress), 'postsnotfound');
		
		// Prepare global variables
		$Data['HasContent'] = FALSE;
	}
	
	
	
	// Provide search content
	public static function Search()
	{
		global $Entity;
		global $Output;
		global $Request;
		global $Data;
		
		$searchPagesContent = '';
		$searchPostsContent = '';
		
		$searchPagesCollection = $Entity->SearchPages();
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `SEARCH` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($searchPagesCollection != NULL)
		{
			foreach ($searchPagesCollection as $searchPages)
			{
				$searchPagesContent .= TemplateProvider::Search(CreateInternalUrl($searchPages->Name), $searchPages->Title, $searchPages->Description);
			}
		}
		
		$searchPostsCollection = $Entity->SearchPosts();
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `SEARCH` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($searchPostsCollection != NULL)
		{
			foreach ($searchPostsCollection as $searchPosts)
			{
				$searchPostsContent .= TemplateProvider::Search(CreateInternalPostUrl($searchPosts->Name), $searchPosts->Title, '');
			}
		}
		
		$Output['Content'] = TemplateProvider::Content(TemplateProvider::SearchContainer($Request, count($searchPagesCollection) + count($searchPostsCollection), count($searchPagesCollection), count($searchPostsCollection), $searchPagesContent, $searchPostsContent), 'searching');
		$Output['PageTitle'] = 'Search...';
		
		// Prepare global variables
		$Data['HasContent'] = TRUE;
		
		unset($searchPagesContent);
		unset($searchPostsContent);
		unset($searchPagesCollection);
		unset($searchPostsCollection);
	}
	
	
	
	// Provide HTML header
	public static function Header()
	{
		global $Output;
		global $Settings;
		global $Data;
		global $ThisPage;
		global $ThisPost;
		global $Store;

		$title = $Output['Title'];
		if ($Settings->IncludePageTitle == TRUE && empty($Output['PageTitle']) == FALSE && ($ThisPage->ID > 1 || $ThisPost->ID > 0))
			$title .= ' : ' . $Output['PageTitle'];
			
		$author = '';
		if (empty($Store['Author']) == FALSE)
		{
			$author = $Store['Author'];
		}
		elseif (empty($Settings->MetaAuthor) == FALSE)
		{			
			$author = $Settings->MetaAuthor;
		}
		
		$description = '';
		if (empty($Settings->MetaDescription) == FALSE)
			$description = $Settings->MetaDescription;
		if (empty($Store['Description']) == FALSE)
		{
			if (empty($Settings->MetaDescription) == FALSE)
				$description .= ', ';
			$description .= $Store['Description'];
		}
		
		$keywords = '';
		if (empty($Settings->MetaKeywords) == FALSE)
			$keywords = $Settings->MetaKeywords;
		if (empty($Store['Keywords']) == FALSE)
		{
			if (empty($Settings->MetaKeywords) == FALSE)
				$keywords .= ', ';
			$keywords .= $Store['Keywords'];
		}
		
		$metastr = '';
		$metastr .= TemplateProvider::MetaExtended('http-equiv', 'Content-Type', 'text/html; charset=utf-8') . "\n";
		$metastr .= TemplateProvider::MetaExtended('http-equiv', 'pragma', 'no-cache') . "\n";
		$metastr .= TemplateProvider::MetaExtended('http-equiv', 'cache-control', 'no-cache') . "\n";
		if (empty($author) == FALSE)
			$metastr .= TemplateProvider::Meta('author', $author) . "\n";
		$metastr .= TemplateProvider::Meta('builder', 'Exsense Dynamix') . "\n";
		$metastr .= TemplateProvider::Meta('copyright', 'Copyright (C) ' . $Output['Title']) . "\n";
		$metastr .= TemplateProvider::Meta('generator', 'Exsense Dynamix') . "\n";
		if (empty($description) == FALSE)
			$metastr .= TemplateProvider::Meta('description', $description) . "\n";
		if (empty($keywords) == FALSE)
			$metastr .= TemplateProvider::Meta('keywords', $keywords) . "\n";
		$metastr .= TemplateProvider::Link(CreateInternalAddress(MEDIAPICTURESDIR . 'favicon.ico'), 'shortcut icon', 'image/x-icon') . "\n";
		$metastr .= TemplateProvider::Link(CreateInternalAddress(MEDIAPICTURESDIR . 'favicon.ico'), 'icon', 'image/x-icon') . "\n";
		$metastr .= PrepareHeaderElements();
		$metastr .= '<title>' . $title . '</title>';
		
		$Output['Header'] = $metastr;
	}
	
	
	
	// Provide title
	public static function Title()
	{
		global $Settings;
		global $Output;
		
		$Output['Title'] = trim($Settings->SiteTitle);
		$Output['Date'] = date("l, F d, Y");
		$Output['Year'] = date("Y");
	}
	
	
	
	// Provide subpages
	// Return: string
	private static function Subpage()
	{
		global $Entity;
		global $Data;
		
		$subpageCollection = $Entity->Subpages();
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `SUBPAGE` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($subpageCollection == NULL)
			return '';
		
		// Prepare global variables
		$Data['SubpageCount'] = count($subpageCollection);
		if ($Data['SubpageCount'] > 0)
			$Data['HasSubpage'] = TRUE;
			
		$subpageContent = '';
		foreach ($subpageCollection as $subpage)
		{
			$subpageContent .= TemplateProvider::ContentSubpage(CreateInternalUrl($subpage->Name), $subpage->Title, $subpage->Description);
		}
		
		unset($subpageCollection);
		
		return TemplateProvider::ContentSubpageContainer($subpageContent);
	}
	
	
	
	// Provide comment
	private static function Comment()
	{
		global $Entity;
		global $Output;
		global $Data;
		
		$commentCollection = $Entity->Comments();
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `COMMENT` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($commentCollection == NULL)
			return;
		
		// Prepare global variables
		$Data['CommentCount'] = count($commentCollection);
		if ($Data['CommentCount'] > 0)
			$Data['HasComment'] = TRUE;
		
		$commentContent = '';
		foreach ($commentCollection as $comment)
		{
			$commentContent .= TemplateProvider::Comment($comment->NamePerson, $comment->Subject, $comment->Message, $comment->CreatedDate);
		}
		
		$Output['Comment'] = TemplateProvider::CommentContainer($commentContent);
		
		unset($commentCollection);
	}
	
	
	
	// Provide menus
	public static function Menu()
	{
		global $Entity;
		global $Output;
		global $Data;
		global $ThisPage;
		global $Settings;
		
		$menuCollection = $Entity->Menus();
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `MENU` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		
		$menuContent1 = '';
		$menuContent2 = '';
		$menuContent3 = '';
		$menuContent4 = '';
		$menuContent5 = '';
		
		// Provide home page menu
		$menuContent1 .= TemplateProvider::Menu('Home', $Settings->SiteTitle . ' home page', CreateInternalUrl('home'), '_self', ($ThisPage->Name == 'home' ? 'menuselected' : ''));
		
		if ($menuCollection != NULL)
		{
			foreach ($menuCollection as $menu)
			{
				if ($menu->Published == TRUE)
				{
					switch ($menu->MenuGroup)
					{
						case 1:
							if ($menu->IsExternal == FALSE)
								$menuContent1 .= TemplateProvider::Menu($menu->Title, $menu->AltText, CreateInternalUrl($menu->PageURL), '_self', ($ThisPage->Name == $menu->PageURL ? 'menuselected' : ''));
							else
								$menuContent1 .= TemplateProvider::Menu($menu->Title, $menu->AltText, $menu->PageURL, '_blank');
							break;
						case 2:
							if ($menu->IsExternal == FALSE)
								$menuContent2 .= TemplateProvider::Menu($menu->Title, $menu->AltText, CreateInternalUrl($menu->PageURL), '_self', ($ThisPage->Name == $menu->PageURL ? 'menuselected' : ''));
							else
								$menuContent2 .= TemplateProvider::Menu($menu->Title, $menu->AltText, $menu->PageURL, '_blank');
							break;
						case 3:
							if ($menu->IsExternal == FALSE)
								$menuContent3 .= TemplateProvider::Menu($menu->Title, $menu->AltText, CreateInternalUrl($menu->PageURL), '_self', ($ThisPage->Name == $menu->PageURL ? 'menuselected' : ''));
							else
								$menuContent3 .= TemplateProvider::Menu($menu->Title, $menu->AltText, $menu->PageURL, '_blank');
							break;
						case 4:
							if ($menu->IsExternal == FALSE)
								$menuContent4 .= TemplateProvider::Menu($menu->Title, $menu->AltText, CreateInternalUrl($menu->PageURL), '_self', ($ThisPage->Name == $menu->PageURL ? 'menuselected' : ''));
							else
								$menuContent4 .= TemplateProvider::Menu($menu->Title, $menu->AltText, $menu->PageURL, '_blank');
							break;
						case 5:
							if ($menu->IsExternal == FALSE)
								$menuContent5 .= TemplateProvider::Menu($menu->Title, $menu->AltText, CreateInternalUrl($menu->PageURL), '_self', ($ThisPage->Name == $menu->PageURL ? 'menuselected' : ''));
							else
								$menuContent5 .= TemplateProvider::Menu($menu->Title, $menu->AltText, $menu->PageURL, '_blank');
							break;
					}
				}
			}
		}
		
		$Output['Menu1'] = (!empty($menuContent1) ? TemplateProvider::MenuContainer($menuContent1) : '');
		$Output['Menu2'] = (!empty($menuContent2) ? TemplateProvider::MenuContainer($menuContent2) : '');
		$Output['Menu3'] = (!empty($menuContent3) ? TemplateProvider::MenuContainer($menuContent3) : '');
		$Output['Menu4'] = (!empty($menuContent4) ? TemplateProvider::MenuContainer($menuContent4) : '');
		$Output['Menu5'] = (!empty($menuContent5) ? TemplateProvider::MenuContainer($menuContent5) : '');
		
		// Prepare global variables
		if (!empty($menuContent1))
			$Data['HasMenu1'] = TRUE;
		if (!empty($menuContent2))
			$Data['HasMenu2'] = TRUE;
		if (!empty($menuContent3))
			$Data['HasMenu3'] = TRUE;
		if (!empty($menuContent4))
			$Data['HasMenu4'] = TRUE;
		if (!empty($menuContent5))
			$Data['HasMenu5'] = TRUE;
			
		unset($menuCollection);
	}
	
	
	
	// Provide panels
	public static function Panel()
	{
		global $Entity;
		global $Output;
		global $Modules;
		global $Data;
		global $ThisPage;
		
		$panelContent1 = '';
		$panelContent2 = '';
		$panelContent3 = '';
		$panelContent4 = '';
		$panelContent5 = '';
		
		
		// Get panels
		if ($ThisPage->ID > 0)
		{
			$panelCollection = $Entity->Panels();
			if ($Entity->HasError())
				ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `PANEL` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
			if ($panelCollection != NULL)
			{
				foreach ($panelCollection as $panel)
				{
					if (empty($panel->StyleClass))
						$panel->StyleClass = 'panel';
					
					switch ($panel->PanelGroup)
					{
						case 1:
							$panelContent1 .= TemplateProvider::Panel($panel->Title, $panel->TextContent, $panel->StyleClass);
							break;
						case 2:
							$panelContent2 .= TemplateProvider::Panel($panel->Title, $panel->TextContent, $panel->StyleClass);
							break;
						case 3:
							$panelContent3 .= TemplateProvider::Panel($panel->Title, $panel->TextContent, $panel->StyleClass);
							break;
						case 4:
							$panelContent4 .= TemplateProvider::Panel($panel->Title, $panel->TextContent, $panel->StyleClass);
							break;
						case 5:
							$panelContent5 .= TemplateProvider::Panel($panel->Title, $panel->TextContent, $panel->StyleClass);
							break;
					}
				}
				unset($panelCollection);
			}
		}
		
		
		// Get onsubpage panels
		if ($ThisPage->ParentID > 0)
		{
			$panelCollectionOnsubpage = $Entity->Panels('ONSUBPAGE');
			if ($Entity->HasError())
				ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `PANEL` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
			if ($panelCollectionOnsubpage != NULL)
			{
				foreach ($panelCollectionOnsubpage as $panelOnsubpage)
				{
					if (empty($panelOnsubpage->StyleClass))
						$panelOnsubpage->StyleClass = 'panel';
					
					switch ($panelOnsubpage->PanelGroup)
					{
						case 1:
							$panelContent1 .= TemplateProvider::Panel($panelOnsubpage->Title, $panelOnsubpage->TextContent, $panelOnsubpage->StyleClass);
							break;
						case 2:
							$panelContent2 .= TemplateProvider::Panel($panelOnsubpage->Title, $panelOnsubpage->TextContent, $panelOnsubpage->StyleClass);
							break;
						case 3:
							$panelContent3 .= TemplateProvider::Panel($panelOnsubpage->Title, $panelOnsubpage->TextContent, $panelOnsubpage->StyleClass);
							break;
						case 4:
							$panelContent4 .= TemplateProvider::Panel($panelOnsubpage->Title, $panelOnsubpage->TextContent, $panelOnsubpage->StyleClass);
							break;
						case 5:
							$panelContent5 .= TemplateProvider::Panel($panelOnsubpage->Title, $panelOnsubpage->TextContent, $panelOnsubpage->StyleClass);
							break;
					}
				}
				unset($panelCollectionOnsubpage);
			}
		}
		
		
		// Get global panels
		$panelCollectionGlobal = $Entity->Panels('GLOBAL');
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `PANEL` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($panelCollectionGlobal != NULL)
		{
			foreach ($panelCollectionGlobal as $panelGlobal)
			{
				if (empty($panelGlobal->StyleClass))
					$panelGlobal->StyleClass = 'panel';
				
				switch ($panelGlobal->PanelGroup)
				{
					case 1:
						$panelContent1 .= TemplateProvider::Panel($panelGlobal->Title, $panelGlobal->TextContent, $panelGlobal->StyleClass);
						break;
					case 2:
						$panelContent2 .= TemplateProvider::Panel($panelGlobal->Title, $panelGlobal->TextContent, $panelGlobal->StyleClass);
						break;
					case 3:
						$panelContent3 .= TemplateProvider::Panel($panelGlobal->Title, $panelGlobal->TextContent, $panelGlobal->StyleClass);
						break;
					case 4:
						$panelContent4 .= TemplateProvider::Panel($panelGlobal->Title, $panelGlobal->TextContent, $panelGlobal->StyleClass);
						break;
					case 5:
						$panelContent5 .= TemplateProvider::Panel($panelGlobal->Title, $panelGlobal->TextContent, $panelGlobal->StyleClass);
						break;
				}
			}
			unset($panelCollectionGlobal);
		}
		
		
		// Get module panels
		$panelModuleCollection = $Modules->PanelModules();
		foreach ($panelModuleCollection as $panelModule)
		{
			if (empty($panelModule->StyleClass))
				$panelModule->StyleClass = 'panel';
			
			switch ($panelModule->PanelGroup)
			{
				case 1:
					$panelContent1 .= TemplateProvider::Panel($panelModule->Title, $panelModule->TextContent, $panelModule->StyleClass);
					break;
				case 2:
					$panelContent2 .= TemplateProvider::Panel($panelModule->Title, $panelModule->TextContent, $panelModule->StyleClass);
					break;
				case 3:
					$panelContent3 .= TemplateProvider::Panel($panelModule->Title, $panelModule->TextContent, $panelModule->StyleClass);
					break;
				case 4:
					$panelContent4 .= TemplateProvider::Panel($panelModule->Title, $panelModule->TextContent, $panelModule->StyleClass);
					break;
				case 5:
					$panelContent5 .= TemplateProvider::Panel($panelModule->Title, $panelModule->TextContent, $panelModule->StyleClass);
					break;
			}
		}
		unset($panelModuleCollection);
		

		$Output['Panel1'] = (!empty($panelContent1) ? TemplateProvider::PanelContainer($panelContent1) : '');
		$Output['Panel2'] = (!empty($panelContent2) ? TemplateProvider::PanelContainer($panelContent2) : '');
		$Output['Panel3'] = (!empty($panelContent3) ? TemplateProvider::PanelContainer($panelContent3) : '');
		$Output['Panel4'] = (!empty($panelContent4) ? TemplateProvider::PanelContainer($panelContent4) : '');
		$Output['Panel5'] = (!empty($panelContent5) ? TemplateProvider::PanelContainer($panelContent5) : '');
		
		// Prepare global variables
		if (!empty($panelContent1))
			$Data['HasPanel1'] = TRUE;
		if (!empty($panelContent2))
			$Data['HasPanel2'] = TRUE;
		if (!empty($panelContent3))
			$Data['HasPanel3'] = TRUE;
		if (!empty($panelContent4))
			$Data['HasPanel4'] = TRUE;
		if (!empty($panelContent5))
			$Data['HasPanel5'] = TRUE;
	}
	
	
	
	// Provide navigator
	public static function Navigator()
	{
		global $Entity;
		global $Output;
		
		$navigatorCollection = $Entity->Navigators();
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `NAVIGATOR` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
			
		$navigatorContent = '';
		if ($navigatorCollection != NULL)
		{
			foreach ($navigatorCollection as $navigator)
			{
				$navigatorContent = TemplateProvider::Navigator(CreateInternalUrl($navigator->Name), $navigator->Title) . $navigatorContent;
			}
		}
		$navigatorContent = TemplateProvider::Navigator(CreateInternalUrl('home'), 'Home') . $navigatorContent;
		
		$Output['Navigator'] = TemplateProvider::NavigatorContainer($navigatorContent);
		
		unset($navigatorCollection);
	}
	
	
	
	// Provide posts
	public static function Posts()
	{
		global $Request;
		global $Data;
		global $Output;
		
		$postsInfo = self::PostsList($Request);
		if ($postsInfo == NULL)
		{
			self::PostsListNotFound();
			return;
		}
		
		$Output['Content'] = TemplateProvider::Content($postsInfo->Content, '');
		
		// Prepare global variables
		$Output['PageTitle'] = 'Posts: ' . $postsInfo->Page . ' of ' . $postsInfo->TotalPages;
		$Data['HasContent'] = TRUE;
	}
	
	
	
	// Provide posts list
	// Parameters: int
	// Return: PostsInformationEntity | NULL
	public static function PostsList($page)
	{
		global $Entity;
		global $Settings;
		
		// Get posts count from database
		$totalRows = $Entity->PostsCount();
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get posts `COUNT` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($totalRows == NULL || $totalRows == 0)
			return NULL;
		
		$totalPages = ceil($totalRows / $Settings->PostsNumber);
		
		// Limit to minimum and maximum
		if ($page < 1)
			$page = 1;
		if ($page > $totalPages)
			return NULL;		
		
		$offset = ($page - 1) * $Settings->PostsNumber;
		
		// Get posts from database
		$postCollection = $Entity->PostsList($Settings->PostsNumber, $offset);
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `POST` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage(), 31);
		if ($postCollection == NULL)
			return NULL;
		
		$content = '';
		$text = '';
		$readmore = TemplateProvider::PostReadMore();
		
		// Prepare post items
		foreach ($postCollection as $post)
		{
			$morePos = strpos($post->TextContent, $readmore);
			if ($morePos === FALSE)
				$text = $post->TextContent;
			else
				$text = substr($post->TextContent, 0, $morePos) . TemplateProvider::PostsListItemMore(CreateInternalPostUrl($post->Name));
			$timestampCreated = strtotime($post->CreatedDate);
			$timestampModified = strtotime($post->ModifiedDate);
			$content .= TemplateProvider::PostsListItem(CreateInternalPostUrl($post->Name), $post->Title, TemplateProvider::PostsListItemDate(date("l, d F Y", $timestampCreated), date("m-d-Y", $timestampCreated), date("l, d F Y", $timestampModified), date("m-d-Y", $timestampModified), date("H:i", $timestampCreated), date("H:i", $timestampModified)) , $text);
		}
		
		unset($text);
		
		$min = 0;
		$max = 0;
		$paginationContent = '';

		// Preivous link
		if ($page > 1)
			$paginationContent .= TemplateProvider::PostsPaginationItem(CreateInternalPostsListUrl($page - 1), $page - 1, '&larr; Previous', '');

		// First link
		if ($page - 2 > 1)
			$paginationContent .= TemplateProvider::PostsPaginationItem(CreateInternalPostsListUrl(1), '1', '1', $page == 1 ? 'selected' : '');
		
		// First dots
		if ($page - 3 > 1)
			$paginationContent .= TemplateProvider::PostsPaginationDots();
		
		// Calculate minimum
		if ($page - 2 > 1)
			$min = $page - 2;
		else
			$min = 1;
		
		// Calculate maximum
		if ($page + 2 < $totalPages)
			$max = $page + 2;
		else
			$max = $totalPages;
		
		// Post links
		for ($counter = $min; $counter < $max + 1; $counter++)
			$paginationContent .= TemplateProvider::PostsPaginationItem(CreateInternalPostsListUrl($counter), $counter, $counter, $page == $counter ? 'selected' : '');
		
		// Last dots
		if ($page + 3 < $totalPages)
			$paginationContent .= TemplateProvider::PostsPaginationDots();
		
		// Last link
		if ($page + 2 < $totalPages)
			$paginationContent .= TemplateProvider::PostsPaginationItem(CreateInternalPostsListUrl($totalPages), $totalPages, $totalPages, $page == $totalPages ? 'selected' : '');
			
		// Next link
		if ($page < $totalPages)
			$paginationContent .= TemplateProvider::PostsPaginationItem(CreateInternalPostsListUrl($page + 1), $page + 1, 'Next &rarr;', '');
		
		// Templates
		$content .= TemplateProvider::PostsPaginationContainer($paginationContent);
		$content = TemplateProvider::PostsListContainer($content);
		
		// Posts Information Entity
		$postsInfo = new PostsInformationEntity();
		$postsInfo->Page = $page;
		$postsInfo->TotalPages = $totalPages;
		$postsInfo->Content = $content;
		
		unset($postCollection);
		unset($content);
		unset($paginationContent);
		
		return $postsInfo;
	}
	
}

?>