<?php

// Database System Class
class DatabaseManagement
{
	private $DatabaseObject;
	public $DatabaseResult;
	
	private $Error;
	private $QueryError;
	
	private $DatabaseType;
	
	
	
	
	
	// Database Management constructor
	function __construct($dbType, $dbHost, $dbUsername, $dbPassword)
	{
		$this->Error = FALSE;
		$this->QueryError = FALSE;
		
		$this->DatabaseType = $dbType;
		
		// Connect to Database
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				$this->DatabaseObject = new MySQLi($dbHost, $dbUsername, $dbPassword);
				break;
			case 'mysql':
				$this->DatabaseObject = mysql_connect($dbHost, $dbUsername, $dbPassword);
				break;
		}
		
		// Check database object
		if ($this->DatabaseObject === NULL)
		{
			$this->Error = TRUE;
			return;
		}
		
		// Check database connection error
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				if ($this->DatabaseObject->connect_errno > 0)
					$this->Error = TRUE;
				break;
			case 'mysql':
				if (!$this->DatabaseObject || mysql_errno($this->DatabaseObject) > 0)
					$this->Error = TRUE;
				break;
		}
		
		// Initializes
		if (!$this->Error)
		{
			$this->SetEncoding();
		}
	}
	
	
	
	// Database Management destructor
	function __destruct()
	{
		$this->DisposeResult();
		
		// Close database connecton
		if (!$this->Error && isset($this->DatabaseObject))
		{
			switch ($this->DatabaseType)
			{
				case 'mysqli':
					$this->DatabaseObject->Close();
					break;
				case 'mysql':
					mysql_close($this->DatabaseObject);
					break;
			}
		}
	}
	
		
	
	// Select and activate a database
	public function SelectDatabase($dbName)
	{
		// Initialize database
		if (!$this->Error)
		{
			switch ($this->DatabaseType)
			{
				case 'mysqli':
					if ($this->DatabaseObject->select_db($dbName) === FALSE)
						$this->Error = TRUE;
					break;
				case 'mysql':
					if (mysql_select_db($dbName, $this->DatabaseObject) === FALSE)
						$this->Error = TRUE;
					break;
			}
		}
	}
	
	
	
	// Dispose, close and release database objects
	public function DisposeResult()
	{
		if ($this->IsResultValid())
		{
			switch ($this->DatabaseType)
			{
				case 'mysqli':
					$this->DatabaseResult->free();
					break;
				case 'mysql':
					mysql_free_result($this->DatabaseResult);
					break;
			}
			
			unset($this->DatabaseResult);
		}
	}
	
	
	
	// Check is result valid as database resource or database result
	// Return: boolean
	private function IsResultValid()
	{
		if (isset($this->DatabaseResult) && ($this->DatabaseResult != FALSE) && ($this->DatabaseResult !== TRUE))
			return TRUE;
		else
			return FALSE;
	}
	
	
	
	// Has connection to database error
	// Return: boolean
	public function HasError()
	{
		return $this->Error;
	}
	
	
	
	// Get last error message
	// Return: string
	public function ErrorMessage()
	{
		if ($this->DatabaseObject === NULL)
			return 'CRITICAL DATABASE ERROR';

		switch ($this->DatabaseType)
		{
			case 'mysqli':
				if ($this->DatabaseObject->connect_errno > 0)
					return mysqli_connect_error();
				else
					return $this->DatabaseObject->error;
				break;
			case 'mysql':
				if (!$this->DatabaseObject)
					return mysql_error();
				else
					return mysql_error($this->DatabaseObject);
				break;
		}
	}
	
	
	
	// Has query to database error
	// Return: boolean
	public function QueryHasError()
	{
		return $this->QueryError;
	}
	
	
	
	// Get last query error message
	// Return: string
	public function QueryErrorMessage()
	{
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				return $this->DatabaseObject->error;
				break;
			case 'mysql':				
				return mysql_error($this->DatabaseObject);
				break;
		}
	}
	
	
	
	// Set database encoding to UTF-8
	private function SetEncoding()
	{
		// [ OBSOLETED ] 
		// $this->Query('SET NAMES utf8'); $this->Query('SET CHARACTER_SET utf8');
		
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				$this->DatabaseObject->set_charset('utf8');
				break;
			case 'mysql':
				mysql_set_charset('utf8', $this->DatabaseObject);
				break;
		}
	}
	
	
	
	// Real Scape String function
	// Parameters: string
	// Return: string
	public function EscapeString($escstring)
	{
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				return $this->DatabaseObject->real_escape_string($escstring);
				break;
			case 'mysql':
				return mysql_real_escape_string($escstring, $this->DatabaseObject);
				break;
		}
	}
	
	
	
	// Make a query without result
	// Parameters: string
	public function QueryExecute($QueryString)
	{
		$qresult = FALSE;
		
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				// [ OBSOLETED ] // if ($this->DatabaseObject->query($QueryString) == false) $qresult = false; else $qresult = true;
				$qresult = $this->DatabaseObject->real_query($QueryString);
				break;
			case 'mysql':
				if (mysql_query($QueryString, $this->DatabaseObject) == FALSE)
					$qresult = FALSE;
				else
					$qresult = TRUE;
				break;
		}
		
		if ($qresult == TRUE)
			$this->QueryError = FALSE;
		else
			$this->QueryError = TRUE;
	}
	
	
	
	// Make a query
	// Parameters: string , boolean
	public function Query($QueryString, $DisposeLastResult = TRUE)
	{
		if ($DisposeLastResult == TRUE)
			$this->DisposeResult();
		
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				$this->DatabaseResult = $this->DatabaseObject->query($QueryString);
				break;
			case 'mysql':
				$this->DatabaseResult = mysql_query($QueryString, $this->DatabaseObject);
				break;
		}
			
		if ($this->DatabaseResult == FALSE)
			$this->QueryError = TRUE;
		else
			$this->QueryError = FALSE;
	}
	
	
	
	// Make a multi query
	// Parameters: array
	// Return: Array | NULL
	public function MultiQuery($QueryStringCollection)
	{
		$resultCollection = array();
		$counter = 0;

		switch ($this->DatabaseType)
		{
			case 'mysqli':
				$flatQuery = '';
				foreach ($QueryStringCollection as $singleQuery)
				{
					$flatQuery .= $singleQuery . ';';
				}
				if ($this->DatabaseObject->multi_query($flatQuery)) 
				{
					do 
					{
						$this->DisposeResult();
						$this->DatabaseResult = $this->DatabaseObject->store_result();
						if ($this->DatabaseResult == FALSE && $this->DatabaseObject->errno > 0)
						{
							$this->QueryError = TRUE;
							$resultCollection[$counter] = FALSE;
						}
						else
						{
							$this->QueryError = FALSE;
							if ($this->GetRowsCount() > 0)
							{
								while ($result = $this->FetchResultExtra())
								{
									$resultCollection[$counter][] = $result;
								}
							}
							else
								$resultCollection[$counter] = TRUE;
						}
						$counter++;
					}
					while ($this->DatabaseObject->more_results() && $this->DatabaseObject->next_result());
				}
				break;
			case 'mysql':
				foreach ($QueryStringCollection as $singleQuery)
				{
					$this->Query($singleQuery);
					if (!$this->QueryHasError())
					{
						if ($this->GetRowsCount() > 0)
						{
							while ($result = $this->FetchResultExtra())
							{
								$resultCollection[$counter][] = $result;
							}
						}
						else
							$resultCollection[$counter] = TRUE;
					}
					else
						$resultCollection[$counter] = FALSE;
					$counter++;
				}
				break;
		}
		
		$this->DisposeResult();
		
		if (count($resultCollection) > 0)
			return $resultCollection;
		else
			return NULL;
	}
	
	
			
	// Fetch data from database query result
	// Return: Associative Array
	public function FetchResult()
	{
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				return $this->DatabaseResult->fetch_assoc();
				break;
			case 'mysql':
				return mysql_fetch_assoc($this->DatabaseResult);
				break;
		}
	}
	
	
	
	// Fetch data from database query result as enumerated array
	// Return: Enumerated Array
	public function FetchResultRow()
	{
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				return $this->DatabaseResult->fetch_row();
				break;
			case 'mysql':
				return mysql_fetch_row($this->DatabaseResult);
				break;
		}
	}
	
	
	
	// Fetch data from database query result as enumerated and associative array
	// Return: Enumerated and Associative Array
	public function FetchResultExtra()
	{
		switch ($this->DatabaseType)
		{
			case 'mysqli':
				return $this->DatabaseResult->fetch_array();
				break;
			case 'mysql':
				return mysql_fetch_array($this->DatabaseResult);
				break;
		}
	}
	
	
	
	// Get the number of rows in result
	// Return: int
	public function GetRowsCount()
	{
		if ($this->IsResultValid())
		{
			switch ($this->DatabaseType)
			{
				case 'mysqli':
					return $this->DatabaseResult->num_rows;
					break;
				case 'mysql':
					return mysql_num_rows($this->DatabaseResult);
					break;
			}
		}
		else
			return 0;
	}
	
	
	
	// Reset result seek to start and first
	public function ResetResult()
	{
		if ($this->IsResultValid())
		{
			switch ($this->DatabaseType)
			{
				case 'mysqli':
					$this->DatabaseResult->data_seek(0);
					break;
				case 'mysql':
					mysql_data_seek($this->DatabaseResult, 0);
					break;
			}
		}
	}
	
}

?>