<?php

// Entity Management
class EntityManagement
{
	private $Error;
	
	
	
	
	
	// Entity Management constructor
	function __construct()
	{
		$this->Error = FALSE;
	}
	
	
	
	// Has entity error
	// Return: boolean
	public function HasError()
	{
		return $this->Error;
	}
	
	
	
	// Get error message
	// Return: string
	public function ErrorMessage()
	{
		global $Database;
		return $Database->QueryErrorMessage();
	}
	
	
	
	// Get a page from database
	// Parameters: string
	// Return: PageEntity | NULL
	public function Page($pageName)
	{
		global $Database;
		
		if (is_numeric($pageName))
			$Database->Query(QueryProvider::PageQueryWithID($pageName));
		else
			$Database->Query(QueryProvider::PageQueryWithName($pageName));
			
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$result = $Database->FetchResult();
		
		if ($result == NULL)
			return NULL;
		
		$page = new PageEntity();
		$page->ID = (int)$result['ID'];
		$page->ParentID = (int)$result['ParentID'];
		$page->Name = $result['Name'];
		$page->Title = $result['Title'];
		$page->Description = $result['Description'];
		$page->TextContent = $result['TextContent'];
		$page->CreatedDate = $result['CreatedDate'];
		$page->ModifiedDate = $result['ModifiedDate'];
		$page->Published = (bool)$result['Published'];
		$page->Counter = (int)$result['Counter'];
		$page->AllowCommenting = (bool)$result['AllowCommenting'];
		$page->ShowComments = (bool)$result['ShowComments'];
		$page->ShowSubpages = (bool)$result['ShowSubpages'];
		$page->ShowTitle = (bool)$result['ShowTitle'];
		$page->ShowDescription = (bool)$result['ShowDescription'];
		$page->ShowDate = (bool)$result['ShowDate'];
		$page->ShowAuthor = (bool)$result['ShowAuthor'];
		$page->Author = $result['Author'];
		$page->MetaDescription = $result['MetaDescription'];
		$page->MetaKeywords = $result['MetaKeywords'];
		$page->StyleClass = $result['StyleClass'];
		
		return $page;
	}
	
	
	
	// Get a post from database
	// Parameters: string
	// Return: PostEntity | NULL
	public function Post($postName)
	{
		global $Database;
		
		if (is_numeric($postName))
			$Database->Query(QueryProvider::PostQueryWithID($postName));
		else
			$Database->Query(QueryProvider::PostQueryWithName($postName));
			
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$result = $Database->FetchResult();
		
		if ($result == NULL)
			return NULL;
		
		$post = new PostEntity();
		$post->ID = (int)$result['ID'];
		$post->Name = $result['Name'];
		$post->Title = $result['Title'];
		$post->TextContent = $result['TextContent'];
		$post->CreatedDate = $result['CreatedDate'];
		$post->ModifiedDate = $result['ModifiedDate'];
		$post->Published = (bool)$result['Published'];
		$post->Counter = (int)$result['Counter'];
		$post->ShowAuthor = (bool)$result['ShowAuthor'];
		$post->Author = $result['Author'];
		$post->MetaDescription = $result['MetaDescription'];
		$post->MetaKeywords = $result['MetaKeywords'];
		$post->StyleClass = $result['StyleClass'];
		
		return $post;
	}
	
	
	
	// Get parent description from database
	// Parameters: int
	// Return: string
	public function ParentDescription($parentID)
	{
		global $Database;
		
		$Database->Query(QueryProvider::ParentDescriptionQuery($parentID));
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$result = $Database->FetchResult();
		
		if ($result == NULL)
			return NULL;
			
		return $result['Description'];
	}
	
	
	
	// Get subpages from database
	// Return: SubpageEntity Array | NULL
	public function Subpages()
	{
		global $Database;
		global $Settings;
		global $ThisPage;
		
		switch ($Settings->SortSubpages)
		{
			case 'none':
				$Database->Query(QueryProvider::SubpageQuery($ThisPage->ID, $Settings->ShowSubpagesDescription));
				break;
			case 'ascending':
				$Database->Query(QueryProvider::SubpageQuerySortAsc($ThisPage->ID, $Settings->ShowSubpagesDescription));
				break;
			case 'descending':
				$Database->Query(QueryProvider::SubpageQuerySortDesc($ThisPage->ID, $Settings->ShowSubpagesDescription));
				break;
		}
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$subpageCollection = array();
		while ($result = $Database->FetchResult())
		{
			$subpage = new SubpageEntity();
			$subpage->Name = $result['Name'];
			$subpage->Title = $result['Title'];
			if ($Settings->ShowSubpagesDescription == true)
				$subpage->Description = $result['Description'];
			else
				$subpage->Description = "";
			
			$subpageCollection[] = $subpage;
		}
		
		return $subpageCollection;
	}
	
	
	
	// Get comments from database
	// Return: CommentEntity Array | NULL
	public function Comments()
	{
		global $Database;
		global $ThisPage;
		
		$Database->Query(QueryProvider::CommentQuery($ThisPage->ID));
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$commentCollection = array();
		while ($result = $Database->FetchResult())
		{
			$comment = new CommentEntity();
			$comment->ID = (int)$result['ID'];
			$comment->NamePerson = $result['NamePerson'];
			$comment->Email = $result['Email'];
			$comment->Subject = $result['Subject'];
			$comment->Message = $result['Message'];
			$comment->CreatedDate = $result['CreatedDate'];
			
			$commentCollection[] = $comment;
		}
		
		return $commentCollection;
	}
	
	
	
	// Get menus from database
	// Return: MenuEntity Array | NULL
	public function Menus()
	{
		global $Database;
		
		$Database->Query(QueryProvider::MenuQuery());
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$menuCollection = array();
		while ($result = $Database->FetchResult())
		{
			$menu = new MenuEntity();
			$menu->ID = (int)$result['ID'];
			$menu->MenuGroup = (int)$result['MenuGroup'];
			$menu->Title = $result['Title'];
			$menu->AltText = $result['AltText'];
			$menu->PageURL = $result['PageURL'];
			$menu->Ordering = (int)$result['Ordering'];
			$menu->Published = (bool)$result['Published'];
			$menu->IsExternal = (bool)$result['IsExternal'];
			
			$menuCollection[] = $menu;
		}
		
		return $menuCollection;
	}
	
	
	
	// Get a panel from database
	// Parameters: ID
	// Return: PanelEntity
	public function Panel($panelID)
	{
		global $Database;
		
		$Database->Query(QueryProvider::PanelQueryWithID($panelID));
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$result = $Database->FetchResult();
		
		if ($result == NULL)
			return NULL;
		
		$panel = new PanelEntity();
		$panel->ID = (int)$result['ID'];
		$panel->PageID = (int)$result['PageID'];
		$panel->PanelGroup = (int)$result['PanelGroup'];
		$panel->Title = $result['Title'];
		$panel->TextContent = $result['TextContent'];
		$panel->ShowOnSubpages = (bool)$result['ShowOnSubpages'];
		$panel->ShowGlobal = (bool)$result['ShowGlobal'];
		$panel->StyleClass = $result['StyleClass'];
		
		return $panel;
	}
	
	
	
	// Get panels from database
	// Parameters: enum(string[NULL,ONSUBPAGE,GLOBAL,ALL])
	// Return: PanelEntity Array | NULL
	public function Panels($panelType = '')
	{
		global $Database;
		global $ThisPage;
		
		switch ($panelType)
		{
			case '':
				$Database->Query(QueryProvider::PanelQuery($ThisPage->ID));
				break;
			case 'ONSUBPAGE':
				$Database->Query(QueryProvider::PanelQueryOnsubpage($ThisPage->ParentID));
				break;
			case 'GLOBAL':
				$Database->Query(QueryProvider::PanelQueryGlobal($ThisPage->ID));
				break;
			case 'ALL':
				$Database->Query(QueryProvider::PanelQueryAll());
				break;
		}
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$panelCollection = array();
		while ($result = $Database->FetchResult())
		{
			$panel = new PanelEntity();
			$panel->ID = (int)$result['ID'];
			$panel->PageID = (int)$result['PageID'];
			$panel->PanelGroup = (int)$result['PanelGroup'];
			$panel->Title = $result['Title'];
			$panel->TextContent = $result['TextContent'];
			$panel->ShowOnSubpages = (bool)$result['ShowOnSubpages'];
			$panel->ShowGlobal = (bool)$result['ShowGlobal'];
			$panel->StyleClass = $result['StyleClass'];
			
			$panelCollection[] = $panel;
		}
		
		return $panelCollection;
	}
	
	
	
	// Get panels list from database
	// Parameters: enum(string[NULL,ALL])
	// Return: PanelEntity Array | NULL
	public function PanelList($panelType = '')
	{
		global $Database;
		global $ThisPage;
		
		switch ($panelType)
		{
			case '':
				$Database->Query(QueryProvider::PanelListQuery($ThisPage->ID));
				break;
			case 'ALL':
				$Database->Query(QueryProvider::PanelListQueryAll());
				break;
		}
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$panelCollection = array();
		while ($result = $Database->FetchResult())
		{
			$panel = new PanelItemEntity();
			$panel->ID = (int)$result['ID'];
			$panel->Title = $result['Title'];

			$panelCollection[] = $panel;
		}
		
		return $panelCollection;
	}
	
	
	
	// Get navigator from database
	// Return: NavigatorEntity Array | NULL
	public function Navigators()
	{
		global $Database;
		global $ThisPage;
		
		$navigatorCollection = array();
		$currentID = $ThisPage->ID;
		
		do
		{
			if ($currentID == 1 || $currentID == 0)
				break;
			
			$Database->Query(QueryProvider::NavigatorQuery($currentID));
			
			if ($Database->QueryHasError())
			{
				$this->Error = TRUE;
				return NULL;
			}
			
			if ($Database->GetRowsCount() == 0)
				break;
				
			$result = $Database->FetchResult();
			
			if ($result == NULL)
				break;
			
			$navigator = new NavigatorEntity();
			$navigator->ParentID = (int)$result['ParentID'];
			$navigator->Name = $result['Name'];
			$navigator->Title = $result['Title'];
			
			$navigatorCollection[] = $navigator;
			
			$currentID = $navigator->ParentID;
		}
		while ($currentID > 0);
		
		return $navigatorCollection;
	}
	
	
	
	// Get search items for pages from database
	// Return: SubpageEntity Array | NULL
	public function SearchPages()
	{
		global $Database;
		global $Request;
		
		$Database->Query(QueryProvider::SearchPagesQuery($Request));
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;

		$searchCollection = array();			
		while ($result = $Database->FetchResult())
		{
			$search = new SubpageEntity();
			$search->Name = $result['Name'];
			$search->Title = $result['Title'];
			$search->Description = $result['Description'];
			
			$searchCollection[] = $search;
		}
		
		return $searchCollection;
	}
	
	
	
	// Get search items for posts from database
	// Return: SubpageEntity Array | NULL
	public function SearchPosts()
	{
		global $Database;
		global $Request;
		
		$Database->Query(QueryProvider::SearchPostsQuery($Request));
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;

		$searchCollection = array();			
		while ($result = $Database->FetchResult())
		{
			$search = new SubpageEntity();
			$search->Name = $result['Name'];
			$search->Title = $result['Title'];
			$search->Description = '';
			
			$searchCollection[] = $search;
		}
		
		return $searchCollection;
	}
	
	
	
	// Get page list from database
	// Parameters: boolean , boolean , boolean , boolean , boolean
	// Return: SubpageEntity Array | NULL
	public function PageList($withID = TRUE, $withName = TRUE, $withTitle = TRUE, $withDescription = TRUE, $withParentID = FALSE, $sortDesc = FALSE)
	{
		global $Database;
		
		$Database->Query(QueryProvider::PageListQuery($withID, $withName, $withTitle, $withDescription, $withParentID, $sortDesc));
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$pageCollection = array();
		while ($result = $Database->FetchResult())
		{
			$page = new SubpageEntity();
			if ($withID == TRUE)
				$page->ID = $result['ID'];
			if ($withName == TRUE)
				$page->Name = $result['Name'];
			if ($withTitle == TRUE)
				$page->Title = $result['Title'];
			if ($withDescription == TRUE)
				$page->Description = $result['Description'];
			if ($withParentID == TRUE)
				$page->ParentID = $result['ParentID'];
			
			$pageCollection[] = $page;
		}
		
		return $pageCollection;
	}
	
	
	
	// Get posts count from database
	// Return: string
	public function PostsCount()
	{
		global $Database;
		
		$Database->Query(QueryProvider::PostsCountQuery());
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$result = $Database->FetchResult();
		
		if ($result == NULL)
			return NULL;
			
		return $result['PostsCount'];
	}
	
	
	
	// Get posts list from database
	// Parameters: int, int
	// Return: PanelItemEntity Array | NULL
	public function PostsList($limit, $offset)
	{
		global $Database;
		
		$Database->Query(QueryProvider::PostsListQuery($limit, $offset));
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
		
		$postCollection = array();
		while ($result = $Database->FetchResult())
		{
			$postItem = new PostsListItemEntity();
			$postItem->ID = $result['ID'];
			$postItem->Name = $result['Name'];
			$postItem->Title = $result['Title'];
			$postItem->TextContent = $result['TextContent'];
			$postItem->CreatedDate = $result['CreatedDate'];
			$postItem->ModifiedDate = $result['ModifiedDate'];
			
			$postCollection[] = $postItem;
		}
		
		return $postCollection;
	}
	
	
	
	// Get post list from database
	// Parameters: boolean , boolean , boolean , boolean , boolean
	// Return: SubpageEntity Array | NULL
	public function PostList($withID = TRUE, $withName = TRUE, $withTitle = TRUE, $sortDesc = FALSE)
	{
		global $Database;
		
		$Database->Query(QueryProvider::PostListQuery($withID, $withName, $withTitle, $sortDesc));
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$postCollection = array();
		while ($result = $Database->FetchResult())
		{
			$postItem = new PostListItemEntity();
			$postItem->ID = $result['ID'];
			$postItem->Name = $result['Name'];
			$postItem->Title = $result['Title'];
			
			$postCollection[] = $postItem;
		}
		
		return $postCollection;
	}
	
	
	
	// Get syndication from database
	// Return: SyndicationEntity Array | NULL
	public function Syndication()
	{
		global $Database;
		
		$Database->Query(QueryProvider::SyndicationQuery());
		
		if ($Database->QueryHasError())
		{
			$this->Error = TRUE;
			return NULL;
		}
		
		if ($Database->GetRowsCount() == 0)
			return NULL;
			
		$contentsCollection = array();
		while ($result = $Database->FetchResult())
		{
			$content = new SyndicationEntity();
			$content->Name = $result['Name'];
			$content->Title = $result['Title'];
			$content->TextContent = $result['TextContent'];
			$content->Category = $result['Category'];
			
			$contentsCollection[] = $content;
		}
		
		return $contentsCollection;
	}
	
}

?>