<?php

// Media system class
class MediaSystem
{
	// Get media list
	// Parameters: string
	// Return: returns MediaEntity Array on success or FALSE on failure
	public static function ListMedia($parentDir)
	{
		$targetfolder = $parentDir;
			
		$mediaCollection = array();
		$fullfilename = '';
	
		$fileArray = scandir(self::GetMediaPath($targetfolder));

		if ($fileArray !== FALSE)
		{
			foreach ($fileArray as $filename)
			{
				$fullfilename = self::CreateFullFilename($targetfolder, $filename);

				if (is_file($fullfilename))
				{
					$media = new MediaEntity();
					$media->Name = $filename;
					$media->Path = $targetfolder;
					$media->FullFilename = $fullfilename;
					$media->Size = filesize($fullfilename);
					
					$mediaCollection[] = $media;
				}
			}
		}
		else
			return FALSE;

		return $mediaCollection;
	}
	
	
	
	// Create a full file name with path by folder name and file name
	// Parameters: string, string
	// Return: string
	private static function CreateFullFilename($folder, $name)
	{
		return sprintf("%s/%s", self::GetMediaPath($folder), $name);
	}
	
	
	
	// Get media folder path
	// Parameters: string
	// Return: string
	private static function GetMediaPath($folder)
	{
		if (empty($folder))
			return MEDIADIR;
		else
			return MEDIADIR . $folder;
	}
	
	
	
	// Add a media
	// Parameters: string, string, string
	// Return: returns TRUE on success or FALSE on failure
	public static function AddMedia($folder, $name, $content)
	{
		$fullfilename = self::CreateFullFilename($folder, $name);
		
		if (file_put_contents($fullfilename, $content) === FALSE)
			return FALSE;
		else
			return TRUE;
	}
	
	
	
	// Delete a media
	// Parameters: string, string
	// Return: returns TRUE on success or FALSE on failure
	public static function DeleteMedia($folder, $name)
	{
		$fullfilename = self::CreateFullFilename($folder, $name);
		
		return unlink($fullfilename);
	}
	
	
	
	// View a media
	// Parameters: string, string
	// Return: return string on success or FALSE on failure
	public static function ViewMedia($folder, $name)
	{
		return file_get_contents(self::CreateFullFilename($folder, $name));
	}

}





//-----------------------------------------------------------------------------------------------------------------------------------------

// Media entity class
class MediaEntity
{
	public $Name;
	public $Path;
	public $Size;
	public $FullFilename;
}

?>