<?php 

// Module, Plugin and Addon system class
class ModuleManagement
{
	private $PanelModuleCollection;
	
	private $XDocModules;
	private $Error;
	
	
	
	
	
	// Module Management constructor
	function __construct()
	{
		$this->Error = FALSE;
		
		// Instantiate XML Document and Load module file
		$this->XDocModules = new DOMDocument();
		if ($this->XDocModules->load(MODULECONFIG) == FALSE)
			$this->Error = TRUE;
		else
			$this->Error = FALSE;
			
		$this->PanelModuleCollection = array();
	}
	
	
	
	// Module Management destructor
	function __destruct()
	{
		unset($this->PanelModuleCollection);
		unset($this->XDocModules);
	}
	
	
	
	// Has modules error
	// Return: boolean
	public function HasError()
	{
		return $this->Error;
	}
	
	
	
	// Load modules
	public function Load()
	{
		// Load modules to module classes
		$moduleElements = $this->XDocModules->documentElement->childNodes;
		foreach ($moduleElements as $element)
		{
			if ($element->nodeType != XML_ELEMENT_NODE)
				continue;
			
			$optionCollection = $element->childNodes;
			
			switch (strtoupper($element->attributes->getNamedItem('Type')->nodeValue))
			{
				case 'PANEL':
					$panel = new PanelModuleEntity();
					$panel->ID = $element->attributes->getNamedItem('ID')->nodeValue;
					$panel->Name = $element->attributes->getNamedItem('Name')->nodeValue;
					$panel->File = $element->attributes->getNamedItem('File')->nodeValue;
					$panel->EntryPoint = $element->attributes->getNamedItem('EntryPoint')->nodeValue;
					foreach ($optionCollection as $option)
					{
						if ($option->nodeType != XML_ELEMENT_NODE)
							continue;
							
						switch (strtoupper($option->nodeName))
						{
							case 'ACTIVED':
								$panel->Actived = StringToBoolean($option->nodeValue);
								break;
							case 'TITLE':
								$panel->Title = $option->nodeValue;
								break;
							case 'PANEL':
								$panel->Panel = (int)$option->nodeValue;
								break;
							case 'STYLECLASS':
								$panel->StyleClass = $option->nodeValue;
								break;
							case 'ISGLOBAL':
								$panel->IsGlobal = StringToBoolean($option->nodeValue);
								break;
							case 'ALWAYSSHOW':
								$panel->AlwaysShow = StringToBoolean($option->nodeValue);
								break;
							case 'SETTINGS':
								$panel->Settings = $this->CreateSettingCollection(strtr($option->nodeValue, ';', '&'));
								break;
						}
					}
					$this->PanelModuleCollection[] = $panel;
					break;
				case 'MENU':
					break;
				case 'COMMENT':
					break;
				case 'CONTENT':
					break;
			}
		}
	}
	
	
	
	// Save modules settings
	public function Save()
	{
		if($this->XDocModules->save(MODULECONFIG) == FALSE)
			$this->Error = TRUE;
		else
			$this->Error = FALSE;
	}
	
	
	
	// Get a module element by id
	// Parameters: int
	// Return: DOMNode
	private function GetModuleElementByID($id)
	{
		$moduleElements = $this->XDocModules->documentElement->childNodes;
		foreach ($moduleElements as $element)
		{
			if ($element->nodeType != XML_ELEMENT_NODE)
				continue;
				
			if ($element->attributes->getNamedItem('ID')->nodeValue == $id)
				return $element;
		}
	}
	
	
	
	// Create setting collection from setting value
	// Parameters: string
	// Return: Assoc Array
	private function CreateSettingCollection($settingValue)
	{
		parse_str($settingValue, $settingCollection);
		return $settingCollection;
	}
	
	
	
	// Do and perform panel work
	// Parameters: PanelModuleEntity
	// Return: string
	private function PerformPanelModule($panelModule)
	{
		include(MODULEDIR . $panelModule->File);
		
		$callback = $panelModule->EntryPoint;
		return $callback($panelModule->Settings);
	}
	
	
	
	// Get panel modules as panel entity
	// Return: PanelEntity Array | NULL
	public function PanelModules()
	{
		global $ThisPage;
		
		$panelCollection = array();
		
		foreach ($this->PanelModuleCollection as $panelModule)
		{
			if ($panelModule->Actived == true && ($ThisPage->ID == 1 || $panelModule->IsGlobal == true))
			{
				$panel = new PanelEntity();
				$panel->ID = 0;
				$panel->PanelGroup = $panelModule->Panel;
				$panel->Title = $panelModule->Title;
				$panel->ShowGlobal = $panelModule->IsGlobal;
				$panel->StyleClass = $panelModule->StyleClass;
				$panel->TextContent = $this->PerformPanelModule($panelModule);
				
				if (empty($panel->TextContent) && $panelModule->AlwaysShow === FALSE)
					continue;
				
				$panelCollection[] = $panel;
			}
		}
		
		return $panelCollection;
	}
	
	
	
	// Get panel modules as collection
	// Return: PanelModule Array	
	public function GetPanelModuleCollection()
	{
		return $this->PanelModuleCollection;
	}
	
	
	
	// Edit panel module
	// Parameters: PanelModuleEntity
	// Return: boolean | returns TRUE on success or FALSE on failure
	public function EditPanelModule($panelModule)
	{
		$element = $this->GetModuleElementByID($panelModule->ID);
		if ($element == NULL)
			return FALSE;
		
		$optionCollection = $element->childNodes;
		if ($optionCollection == NULL)
			return FALSE;
		
		foreach ($optionCollection as $option)
		{
			if ($option->nodeType != XML_ELEMENT_NODE)
				continue;
				
			switch (strtoupper($option->nodeName))
			{
				case 'ACTIVED':
					$option->nodeValue = BooleanToString($panelModule->Actived);
					break;
				case 'TITLE':
					$option->nodeValue = $panelModule->Title;
					break;
				case 'PANEL':
					$option->nodeValue = $panelModule->Panel;
					break;
				case 'STYLECLASS':
					$option->nodeValue = $panelModule->StyleClass;
					break;
				case 'ISGLOBAL':
					$option->nodeValue = BooleanToString($panelModule->IsGlobal);
					break;
				case 'ALWAYSSHOW':
					$option->nodeValue = BooleanToString($panelModule->AlwaysShow);
					break;
				case 'SETTINGS':
					$setting = '';
					foreach ($panelModule->Settings as $settingKey => $settingValue)
					{
						if (!empty($setting))
							$setting .= ';';
						$setting .= sprintf("%s=%s", $settingKey, $settingValue);
					}
					$option->nodeValue = $setting;
					break;
			}
		}
		
		return TRUE;
	}
	
}





//-----------------------------------------------------------------------------------------------------------------------------------------

// Panel module entity class
class PanelModuleEntity
{
	public $ID;
	public $Name;
	public $File;
	public $EntryPoint;
	public $Actived;
	public $Title;
	public $Panel;
	public $StyleClass;
	public $IsGlobal;
	public $AlwaysShow;
	public $Settings;
}

?>