<?php

// Option Provider class
class OptionProvider
{
	// Provide feedback comment
	public static function CommentFeedback()
	{
		global $Output;
		global $Settings;
		global $Database;
		
		$Output['PageTitle'] = 'Comment Feedback';
		
		// Check post data integration
		if (!isset($_POST['CommentPageID']) || !is_numeric($_POST['CommentPageID']) || !isset($_POST['CommentName']) || !isset($_POST['CommentEmail']) || !isset($_POST['CommentSubject']) || !isset($_POST['CommentMessage']))
			ShowError('Comment Error', 'Missing Informations for Comment', 'Please enter information for comment');
		
		// Validate post data
		$commentPageID = (int)preg_replace("([^0-9])", "", $_POST['CommentPageID']);
		$commentName = preg_replace("([^a-zA-Z0-9\s])", "", $_POST['CommentName']);
		$commentEmail = $Database->EscapeString(filter_var($_POST['CommentEmail'], FILTER_SANITIZE_EMAIL));
		$commentSubject = preg_replace("([^a-zA-Z0-9\s_])", "", $_POST['CommentSubject']);
		$commentMessage = str_replace("\n", '<br />', str_replace("\r\n", '<br />', htmlspecialchars($_POST['CommentMessage'], ENT_QUOTES)));
		$commentDate = date("Y-m-d H:i:s");
		
		// Get desire page and check page existance
		$Database->Query(QueryProvider::PageQueryCommentFeedback($commentPageID));
		//
		if ($Database->QueryHasError())
		{
			$Output['Content'] = TemplateProvider::Content(TemplateProvider::Error("Error: Can't send your comment.<br />" . 'please contact the <a href="mailto:' . $Settings->EmailAddress . '" title="' . $Output['Title'] . '">' . $Output['Title'] . '</a> support team.'), 'commentfeedback');
			return;
		}
		//
		if ($Database->GetRowsCount() == 0)
		{
			$Output['Content'] = TemplateProvider::Content(TemplateProvider::Error("Error: page not found."), 'commentfeedback');
			return;
		}
		//
		$result = $Database->FetchResult();		
		if ($result == NULL)
		{
			$Output['Content'] = TemplateProvider::Content(TemplateProvider::Error("Error: Can't send your comment.<br />" . 'please contact the <a href="mailto:' . $Settings->EmailAddress . '" title="' . $Output['Title'] . '">' . $Output['Title'] . '</a> support team.'), 'commentfeedback');
			return;
		}
				
		$pageID = (int)$result['ID'];
		$pageTitle = $result['Title'];
		$allowCommenting = (bool)$result['AllowCommenting'];
		
		// Check for allow commenting
		if ($allowCommenting === FALSE)
		{
			$Output['Content'] = TemplateProvider::Content(TemplateProvider::Error("Error: commenting is not allowed."), 'commentfeedback');
			return;
		}
		
		// Insert and save comment to database
		if (CommandProvider::InsertComment($pageID, $commentName, $commentEmail, $commentSubject, $commentMessage, $commentDate) == TRUE)
		{
			$returnContent = '<a href="' . CreateInternalUrl($pageID) . '" title="Return to commented page">Click here to return</a>';
			$Output['Content'] = TemplateProvider::Content(TemplateProvider::Message('Your comment successfuly saved.' . '<br />' . 'Page: ' . $pageTitle . '<br />' . $returnContent), 'commentfeedback');
			$Output['Comment'] = TemplateProvider::CommentContainer(TemplateProvider::CommentFeedback($commentName, $commentEmail, $commentSubject, $commentMessage, $commentDate));
		}
		else
			$Output['Content'] = TemplateProvider::Content($Theme->StylingError("Error: Can't send your comment.<br />" . 'please contact the <a href="mailto:' . $Settings->EmailAddress . '" title="' . $Output['Title'] . '">' . $Output['Title'] . '</a> support team.'), 'commentfeedback');
	}
	
	
	
	// Provide syndication
	public static function Syndication()
	{
		global $Output;
		global $Settings;
		global $Entity;
		global $Data;

		$syndContent = '';

		$contentsCollection = $Entity->Syndication();
		if ($Entity->HasError())
			ShowError('Error', 'Database Error', 'There is a database error.<br />Can\'t fetch and get `Contents` data from database.<br /><br /><strong>Error Message:</strong><br />' . $Entity->ErrorMessage());
		if ($contentsCollection != NULL)
		{
			$link = '';
			
			foreach ($contentsCollection as $contentItem)
			{
				switch ($contentItem->Category)
				{
					case 'PAGE':
						$link = CreateInternalUrl($contentItem->Name);
						break;
					case 'POST':
						$link = CreateInternalPostUrl($contentItem->Name);
						break;
				}
				
				$syndContent .= TemplateProvider::SyndicationItem($contentItem->Title, $link, $contentItem->TextContent);
			}
		}
		
		$Output['Content'] = TemplateProvider::Syndication($Output['Title'], $Data['SiteUrl'], $Settings->EmailAddress, $syndContent);

		unset($contentsCollection);
		
		header('Content-type: text/xml');
		echo $Output['Content'];
		exit();
	}
	
	
	
	// Provide theme outline
	public static function ThemeOutline()
	{
		global $Output;
		global $Data;
		global $Theme;
		
		$Output['Menu1'] = "{MENU1}";
		$Output['Menu2'] = "{MENU2}";
		$Output['Menu3'] = "{MENU3}";
		$Output['Menu4'] = "{MENU4}";
		$Output['Menu5'] = "{MENU5}";
		$Output['Navigator'] = "{NAVIGATOR}";
		$Output['Panel1'] = "{PANEL1}";
		$Output['Panel2'] = "{PANEL2}";
		$Output['Panel3'] = "{PANEL3}";
		$Output['Panel4'] = "{PANEL4}";
		$Output['Panel5'] = "{PANEL5}";
		$Output['Comment'] = "{COMMENT}";
		$Output['Content'] = "{CONTENT}";
		$Output['Title'] = "{TITLE}";
		$Output['PageTitle'] = "{PAGETITLE}";
		$Output['Date'] = "{DATE}";
		
		$Data['HasContent'] = TRUE;
		$Data['HasComment'] = TRUE;
		$Data['CommentCount'] = 1;
		$Data['HasSubpage'] = TRUE;
		$Data['SubpageCount'] = 1;
		$Data['HasPanel1'] = TRUE;
		$Data['HasPanel2'] = TRUE;
		$Data['HasPanel3'] = TRUE;
		$Data['HasPanel4'] = TRUE;
		$Data['HasPanel5'] = TRUE;
		$Data['HasMenu1'] = TRUE;
		$Data['HasMenu2'] = TRUE;
		$Data['HasMenu3'] = TRUE;
		$Data['HasMenu4'] = TRUE;
		$Data['HasMenu5'] = TRUE;
		
		ContentProvider::Header();
		
		echo $Theme->PerformRender();
		exit();
	}
	
}

?>