<?php

// Theme System class
class ThemeSystem
{
	private $XDocTheme;
	private $Error;
	
	private $collectionStylesheets;
	private $collectionScripts;
	
	
		
	public function __construct()
	{
		$this->Error = FALSE;
		
		// Instantiate XML Document and Load Theme file
		$this->XDocTheme = new DOMDocument();
		if ($this->XDocTheme->load(THEMEELEMENTSFILE) == FALSE)
			$this->Error = TRUE;
		else
			$this->Error = FALSE;
		
		// Instantiate collections
		$this->collectionStylesheets = array();
		$this->collectionScripts = array();
	}
	
	function __destruct()
	{
		unset($this->collectionStylesheets);
		unset($this->collectionScripts);
		unset($this->XDocTheme);
	}
	
	
	
	// Has theme system error
	// Return: boolean
	public function HasError()
	{
		return $this->Error;
	}
	
	// Load theme system elements
	public function Load()
	{
		$StylesheetElements = $this->XDocTheme->documentElement->getElementsByTagName('Stylesheet');
		foreach ($StylesheetElements as $elementStylesheet)
		{
			$stylesheet = new ThemeElementEntity();
			$stylesheet->Filename = $elementStylesheet->nodeValue;
			if ($elementStylesheet->hasAttributes() === TRUE)
				$stylesheet->Condition = $elementStylesheet->attributes->getNamedItem('Condition')->nodeValue;
			else
				$stylesheet->Condition = '';
				
			$this->collectionStylesheets[] = $stylesheet;
		}
		
		$ScriptsElements = $this->XDocTheme->documentElement->getElementsByTagName('Script');
		foreach ($ScriptsElements as $elementScript)
		{
			$script = new ThemeElementEntity();
			$script->Filename = $elementScript->nodeValue;
			if ($elementScript->hasAttributes() === TRUE)
				$script->Condition = $elementScript->attributes->getNamedItem('Condition')->nodeValue;
			else
				$script->Condition = '';
				
			$this->collectionScripts[] = $script;
		}
	}
	
	// Get stylesheet collection
	// Return: ThemeElementEntity Array
	public function GetStylesheets()
	{
		return $this->collectionStylesheets;
	}
	
	// Get script collection
	// Return: ThemeElementEntity Array
	public function GetScripts()
	{
		return $this->collectionScripts;
	}
	
	
	
	// Get templates collection
	// Return: TemplateElementEntity Array
	public static function GetTemplates()
	{
		$templateCollection = array();
		
		$fileArray = scandir(TEMPLATESDIR);
		if ($fileArray !== FALSE)
		{
			foreach ($fileArray as $filename)
			{
				$fullfilename = TEMPLATESDIR . $filename;

				if (is_file($fullfilename))
					$templateCollection[] = $filename;
			}
		}
		
		return $templateCollection;
	}
		
	// Get theme file content
	// Return: string | FALSE
	public static function GetSkinContent()
	{
		return file_get_contents(THEMEDIR . 'theme.html');
	}
	
	// Get stylesheet file content
	// Parameters: string
	// Return: string | FALSE
	public static function GetStylesheetContent($filename)
	{
		return file_get_contents(THEMEDIR . $filename);
	}
	
	// Get script file content
	// Parameters: string
	// Return: string | FALSE
	public static function GetScriptContent($filename)
	{
		return file_get_contents(THEMEDIR . $filename);
	}
	
	// Get template file content
	// Parameters: string
	// Return: string | FALSE
	public static function GetTemplateContent($filename)
	{
		return file_get_contents(TEMPLATESDIR . $filename);
	}
	
	// Set theme file content
	// Parameters: string
	// Return: boolean
	public static function SetSkinContent($content)
	{
		if (file_put_contents(THEMEDIR . 'theme.html', $content) === FALSE)
			return FALSE;
		else
			return TRUE;
	}
	
	// Set stylesheet file content
	// Parameters: string, string
	// Return: boolean
	public static function SetStylesheetContent($filename, $content)
	{
		if (file_put_contents(THEMEDIR . $filename, $content) === FALSE)
			return FALSE;
		else
			return TRUE;
	}
	
	// Set script file content
	// Parameters: string, string
	// Return: boolean
	public static function SetScriptContent($filename, $content)
	{
		if (file_put_contents(THEMEDIR . $filename, $content) === FALSE)
			return FALSE;
		else
			return TRUE;
	}
	
	// Set template file content
	// Parameters: string, string
	// Return: boolean
	public static function SetTemplateContent($filename, $content)
	{
		if (file_put_contents(TEMPLATESDIR . $filename, $content) === FALSE)
			return FALSE;
		else
			return TRUE;
	}
}










//-----------------------------------------------------------------------------------------------------------------------------------------

// Theme Element entity class
class ThemeElementEntity
{
	public $Filename;
	public $Condition;
}

?>